#
# Bicodon Frequency Table
#
# The data in this table is derived from the CoCoPUTs codon usage database [1].
# Automatically generated using tools/prepare-bicodon-usage.py on 2023-08-20 21:41:16.
#
# [1] Alexaki et al. (2019) Codon and Codon-Pair Usage Tables (CoCoPUTs):
#     facilitating genetic variation analyses and recombinant gene design.
#     Journal of Molecular Biology. 2019
#

import numpy as np
from base64 import a85decode

def _(b):
    return np.frombuffer(a85decode(b), dtype=np.float16)

bicodon_usage = {}

bicodon_usage['Macaca mulatta'] = _(rb'''
#rCBt=?!oU83Proc+$,'Y<31R:-&nIS2h9F7QdY4Rl-j")*/'dI6?pYUqBbk\#\u(P,p+@FLW-j[Q(iN
!'MYjni96($9U:1"MKpZ83JglBfJ%2=u3??,s66.pH"L#:b(EdLHF][i4N5U76Iq:(-G,NCUKHg9XX"F
5s.\$83Q<#%m<HHgb4%:83KL,[l`,#kd*fC83Km4RPIDs83M5Z-9Og^r303aJhonX/ioE,`jlU?83Q)a
e%>^fd'Fq.-G,[$_7W"E[^u-jOg=PkDnk27a>cAslSh?t9<rb'nM3Tp!P>3e83KL,83LfPfsjR9'ep+Z
9KYj/83OFEf/u,XE\sXTj#fjq83P'U@PgV=83IPIWAR4083IJFnN9?*MlLbZf-S[$gH#YKNk&[W83P(r
VE5DR83K4#c8eEYZaFg7JN-gq5rb>h!k>-d83I;7Y;f'90fD9Y?p"BMQFKLJ83OFD83MA_@(AfkKX=*0
DE@qYZ8PTA*]bE%jh.0E,WML%hm)"7i3KgH0K=hJ.l%AiBK=3q1d'#ABtYQM0sLegq6o1iS@\0rHnhlS
83QH)K0)UeE'-ZSFM+_<83JUg[Q<G.q_Z5O83M&U*&V%^"1_Pp=Z>q-jhCdU5da7jp*tbOA[3"/I3r5\
I5ZR34#Hpsjtm^T282[;9K^q15WQ,$/@dUJJMWb!#cq2jd5`g>nN>Sf=1M'gI(-SlCGKk>X1OY*(-*bN
83J^ji]KapA3<CGgULfW<'8Dd2E<$@-E,cX_)rl"'0'VY6T9ZP@5\':QbB(O`B(-/3]PZ_i3u1S4gptB
F?2rU83Q)qLcS'iC97@m<BNf883N.rM7?)>83Mehgp'C583NA#83J4\P;A7^oH-O`iB*+-b.G>G83MC,
9=u%F!A9,=4M2O]l+@bD3P;W$dC*u-hS8`iAiNl*6T.IuBes3X'K;XFiOFP"83KL,83NP*&@tCqY;)S-
<PBKf^q>iEq7VQsQGC\Yft(\,Dn,)I:;LnaOLqO-s1c:L$*b\e_m8J`41Y6oC;2.(Wi]gI:r$qZs#2^J
?FgfT\hZ+QQae7tL:\84ZFM889=AlRS%m%T:cJBeA%@u<e?A\[3PE/;1V`XrfdoG"-86(D5eqZW._a-=
Gcfr50=_7_QEYSC/AR=Qc7b9j9=H[fm_&G.YdB%im&Ok^FZRo1!BnI`_RYsph(W9<EAEH\+hOe_A2r>K
#<Z]\X?,,t`]=Af2SAfG83KI(K/iuk'eWTJ83P'Re?:>ZlaAdW1H%TRd_<1MLc3YdpbZk</%2uDdk;+e
?T])cdlBr^83QW+:V!Jf83LHD2`];Ia#K8B%Qup;Ou+4B#<?cd$TV-Dqn5rhK=:<[=LY!9-+a\rCc"nh
dlb?+Z9(T?X?$MHcb(hj'g6q*XuB`H;`D0GA3@Cad5bAkG;,aMY;M4_9#%5]83LOhX>;4[ZFITJMR[ag
,<SL[83OOGgH.qhPd9C2Ouu8u,X$N7XgU>T_E>Om"0>$V83IDB-TXd][BE%]b;MmS+$Ffr5eIjm83N]J
8@u)_%lb64T"6I5)8#aT&%Q=5\MM(6\\MjeAMdZ+f/"U68hG!B=g!ZB_S#CkGW\M[\3._k=hN!A?*qs=
AN[Ue83OsRG!+bHm[um/GWY%L`]HIE&26X983JC^'dQO:5<O]^h`/J6F19ma/@W9rOu0GU@(R/V>rrG%
(-&idZ9#ZY/2_!"pUYE&<&=A2:p]u%`3qrlh)j2^OKhhD_QN5YdkMFiI_F/an2Ys$C,RlQ34u^UN4I_%
f/B]cA@*".<id7IYJ=)=HS6YUM7.N;&A%8;S$'.KUUBMD&Mt^g>;([aBYS%9r33oA.C+B1e@j2=jffu>
1He2jgcS+j&N]kQpq+p8dl^/a"?\J$\$tZ[6oo3?]<mq_V79\aVR;2gF2<7-hR1hC_m[Okh7.'iXL:\Y
d5B@Z?neuF+gEB+pqVruE\tD=rNr-)<4pSj8ZY:ecFQ3MCUFAN2)2kUrP0I'`k28cR_7+_$bun\%D9$[
kr@Y!="+nD6o>IS=MP:t.PWKaQb&Tqg:/B>(p5Eu4tH!2hn-P(l*C2sC;C:`2Cp5f7\PC;7D6mS%_[r^
0fqoh83PKaW]E[6pp%@i(-G,NdlO']I^hp383N%pI'cF-83OFB1-A)j6DYtj%66sB,X!k;BtHYj83Pn8
9=fC,l8?;_l*uL/EkJljCUqqOGU[sOs1OOLO?17j=uSu8I5+b`O#H_pFLka<83KL,83MGa3kIpG_Q>OR
aZDRI83KL,=$0#:<3SPK83KL,0Kl<q:Gta,83InT4toMj83KO,)a-JMPHIG>hPc,d`B$l(#J$6N83L.T
)a#B/83KL,br\HZA1^S>)a$YS"?Sq0(:4f483P]`;*.<3LR"Dmj?)Qf:p`5G83J:_83KL,:UjaoU81=C
juEI;mk]MRQ8#PNOhaqu"ZGAL't,d&:q@.G75+-dihkKk]K32Xc9)@n\\(6lF?!qaRkWA;.D(VIjtoFT
83M,Yr]<Y6.m1d5,.pH083JmoB0&UF:G]pL83Mkllo9)Enh?q%_Dk+Fe\A[W#<1tMLGuLr:pOCa].D&`
l)kmR5-8EVC,@3?K"e0;kVo':CSTjj/@Djj-o$K1Q+PSU;mg\A'=B=#S%r@<5.sD!?G-udjh>KCOgtV-
\i5'p-SL`FM(L\79#)L=1-%-JX<AXfX145"Rkn*P-Fgb!-bW`c(V;N;6c'GIfXupL&\5ca`P2Pe(Vnq4
E'$TR83N>%69Rk&'02dL'KnuM83L$7=0kF\83LECTX%*O83Q&o(Hb5OSMi#]N&=3iJin@_oXcV383INi
d^YT$GW8p5m'@osgU:k)`jA]+?8YWkXM(tqQ96J)D_O^F5ck>RP:C9*kdZlu83KL,83ItTl+9JLTs;Ns
JicLd83I;CTKGb.RPQobr&dM583K-toJ&m"83J%WEMc8i83PH`5<MJ".kP^&lR2-]rB%3f%_@6N83I'M
HoX_\83K1"fJlDb]!Ak,pGb],]/Ml1kI@<E83K9m4X`ia4ts6(_`54f$bMif83KL,83I;Cr4=.9E48A$
.6&;$+#Mk6'K0/Gf"JLQjY8$jYI(dI$b>f6__-j'!Nb0;H985g"?QlKRC`Yc/1MRDHS+Zm[(IWloJ$'H
83IGGP<;B!#!>F>/%N/P83J=`eN4C)[4iLZ83IMFLGDR_=L-C9(,Wu]%);0e1,O]kGd7CKb.%j>]s6KV
[kq#B[Q*2+qDYr<]"O[lGWMG$E&aGqLq1a=mPQi#BXMe>c8lOt[6+OR,d`7f_6qCl3&&jnS\2J;[5e`(
G<CgH,!AI[Qodi%Kt6,'^HAS[(Hc%aO0qt:jZ;-O.(8Lk#e*tr#UlGs)8B0,'/l_nSMi?qL:U#0Gdh$?
Hoae]83LHC&irQH>;::\#s1[@83OpMHFcX183N%nA@4rk83J@]M*0*AQSrqH;_qZ>eN>:j-bWnF83M+'
2SA!*O#MU"$+sS%(V'(KcFGqo`\^?%_SF.$\ho5X.'uN.67e0Y.O_AXU:@id83KL,83Jjk>.dBh*&1,I
i4]`9#e[X[P.nTAc+b".[Ci]U%Cj6hVnloYL:lrh[(m'90run=9seUnfIZBpkIqS5OfAl+K>8\Adl1OH
2S4mL[P'8D'>46#;n?2ERCF(k$Ed4<:;Pu'B<gd;U;><hYJ*35.DMOf4MXt2Tsc#QZaEB;U;:<NgV8$H
2(BNP!jk<KYb]gSK>1*]N3Te&^:659n[^Ha#:.]uorr$h[QAds5Wsla41.UBD_b%iNArl*^:NV_-Teso
jZ@6?83O[Lm5b\>S@C:983K!s1-O8M1pR!<83I2:(:5tZ4Lh4I+#L2ZJ%c.Im4g^S4uN!eo<e9P#;f(6
['MEm0saiX[5#Cr@D:kE.5:lN#I(;2]=A*LFuQKP6+m"G=KG1NgU0ec,J[iu(qhB2bdr5:qn<ZT"10Gg
?S]tebVlFZc)3uijh)]a6T9i^-T+Z)5I=fT>s&'<j1"E[$GXKd)7cQR#f3mWmB<4p[^@g#5JEr&MS>Rc
n[7R;Lc>RJ"ZB.=FY_sYc`p#(/N>DYd(Mt5Z91]/Q+JY37QW[iGp`SMC:EK2fXS1IfJrl@:qaM"krdD)
jhU`#I'ffcf"O.!$+]oGgV)#n.Bg%kIDB?p@QS>>YI[7f&\24-/YWqAm'`<8OuZ&r83P$R-GN)7'>+3"
6o2D6T/to3;E42-jKQcXI5D3k/3;dih74(W5WVW@Pdj7I83NJ#C,\[HCbU])N41W)9KZXlT"LFJ83Ol$
Cc&F[83N1q))t/M\YK3`e2'WY5Vd5X+1Qe\83K,F,/;GS3kLZd34QUIcb>LM!%;rr`@eg69"tt:?G/)%
cFg?ocFl]\[_"i8k.kN<>J8@pG.ptin@gflMnAquK"dJQT!Ss64LsL^ZbS9(:q[:M%D*.bEPFlRPdI$p
$Fp;F:9c7UK"3cpoY2rdQ)d).9e?XZhRO%N:HTi+@_KI_,/;R7\%%L+,/GY-gq'o*M7>4NC;/3)Q+T8e
Xgfpl1q4ned^Xb<'#Ae'aLOFG]"8'V^:fE;@'p][f=anj^pnErGeAmGkeRb@354=bhRlV!FMYN'h7YJW
41Z9AB"OYFEkUJGSANL`>eE86'Y][D]YKH@+MBhO+L`W0U:[tJO1d`ko>3r07CG:k"1oA^dD:^S35Gj4
kHIK?'fcCXh)FX^BsCr'LomI8MDSQsppipYK02FZ4M<L,^+lakZE20HmCQH$<OE47Qo3^3KYQERUc#m!
YJE03d_COO"MmdF*l<lO;8CAfWkG=G_8>0F+M:OerN&OQk:,RSeM&a?)7u1m83KL,"$FI^^qWE'FhEGg
'KH^f83L-=@6-qBOXfNS3B0PmQodVo;n/bc83LoL#.[8f83OgJJi6._-aH-$?*]5I83J9*$GAka83NWU
Lc.de83JFaGVr#TBXP`;RPm]"`AsYA^:Fb.83I?icS:;>68j$J&N)=+hm^<Z$p>Rn83Kj4XhV"t1V8r3
A%:1#X1D7apU%N@9#/'+rjeB-qRir@>J-K9]<I*j]t0-(BIbqtXtV-+(V_FW9<a>dVm;]$s1[=$['e&g
NjpdRQ+Q(\a15lop;-=/VPt]HZ+%BUHbDANiO*%(T!,f5A@au`f-k)[,f'=:X"^!Jo9q$]/\Zq=0YI-2
5WOcah)IqgLchFm)S-SD83O.9M)o?3dQ-GNK08]ei[eLt7Q9Tn>W8Q1Kt_Xf%^>B0!3B;48A)XHI4qb1
l8t.i><,5;!]agP-b_u/f/u,V*'.(ZIk2cmcT.j\!'B:&JMTh[HSs5*T=tpuloG/)[l[,DrOFmJkda5I
UH;"083M2ZRQO,(K/CA)83KL,i&l<HT<q-P83J4[:b5.#83I#890,U,*jG5tNAb?00KcJ=(V=]I83OAa
[CfVE!A,;&?+g(hmCT=/%_Ma!m%ed:/AOugT/R=q!@UK%qCWdNM)!^EICSu083KL,83OaN!kLoc+YX3b
M`Om$83KF'Y<,9<5;U>?YWPH>.m4V.q4gJD83LQH40V7=83JUe7QX.(E%YQ\o.P#Dkr^f.!PEP/83PD1
%lgCJ83Mhk))k)L$aE;a@Q$b?V)]eXY.:)Z83J9(4#uUhAhsoY#rR#h*P"-h83J%U83Q?$K"VXW[(4.<
69:o"JMa>d&2lX,e\/(C;)UbM%(9cU7^I"e=uLI_%@f%1+ZT'QPrAt,CVGH_`2b>q!jOYlkIg]"N@d&n
83Nb2XZT-;niB<)T"<9283K+!C-9Ntnh4!'83P6YC8=0U6+4Kh'eu(1J\MaV73OFn33GD$J%$IYH`Y7K
9.V?hq'^eQ'r31dQG3F-+>rl&CSp!t>.b9V<3:APB=cSJE\d#;p,J9rY.OZm8A!Hb*Oa/)hS*^:/u:&0
O$$9%83KL,2`caW9t==e;`m!$>W[Hpe[Y"SGWGW)A@I#t+1h+cbHndco"XoPZET;!la9[!J\AM&G.]F\
<B*N483K7"TK5V,#r#gJff;SdQ95I5Lq-&>83LNDPdj7I83N4taui3XfJpQ,IkUFT83MO4,/$#m83QjZ
*P7@lM`DT`_n/])7_"Df<k5OsS2X'QYeXVT_`*7`>bjnRBeK-?)`:SW<jca'83KL,83MqnA\:PsSebEg
T"nLDq7\i(AAEr67DVO1k.Y6;42"k6`56W3:qj$H.)He/Q+:8:41iTmjL=op9u)dt.^[aAqS<HNUSm[u
LqLF$M_c0\"h](<R'Qb&E4L-O&i/1Q3Ph].X0PR;OMF#nbeGdE-,;"CGeh#,:V=c]Cq=Z$/An-p!l5>\
::F`DH+?hY0=,#p-bp%s6+C@:NP$sX>.s+1OgQLCo=8NlRPqi;dlIdre[h>6j0[^Pkp@Xeot?3mLGTaV
^H3u07m6N-763t&H+7BI00Mih%m>;$[^G`b83KU'BXic#Fh/DE_^TL[%DQg=::Bu+e?*\jft.D>iNr_E
WBBN/_`C=O$9<Gj5J:ei6p/185WA$^jKI8m;EKRlNNGo5/NEtl&2q]j!5?H2NjcR.]!L;*$,$q\GGX-'
1d1In7m-o:%m!?G*4tT!kr`K=4?6q3H8EQ#.6Mu<!OiZL.^mYS0=ZkKrP64V4t*qO?*N1nS@`C=DS&V&
X#eip$9]q#5rhJ!;mC*t]/`DF\iTOCi42BA83Hr5aKnE#83J^e]fAVH(92[Bn1mNtX??*KZb.D@83J`4
?bL\8L,Y%$ke$LI(:HZC@_)4qh_aW.B"nd4L-'=bhQTO6QnLcd@&#YCM7T`G83KL,83J4ZMnDSD.'e(X
1H[TX83K^-JMfSNcFLV=[5L?,#<.RN1q`iCP<$:[V7>JAoK0^j8iLQKYdAa;hRGU'[l&B@&ADeX4$3;K
m5@Ku83L`K3]0Gk#IKUR%PUF:27J/g0"L((8j"OR)SPLH@(-0JpU[H7>JM)c681d<$b-SVH,!@im(?Z6
?*nsfCV::gkdWje28N"sT",`P!ksH'e\.olE4Ou;-+\&sF"/Z>BWgVV/%u-D1q<UtU:FsL<54@&P-Xel
,WHc)pGO?ZR5)]BK"YnZC-%P@f/U,sD6VeU83J@]GIbi$`OUDs/%Tu7O26RVZFOkb8@bn5Z+S,`a181G
V6$JuH*pd6Q*!uqK#$0Hn#SL\'t?lJO1`cNo<dkn=1TH^*O7%<ij<"%Nknr+VRi>2FLq%UM81j]^q:l*
kHIssQFS$@j10]O/],H:Cq,)0c+JJ<[D&BM=1igl\@Wila1HCKj0cV15f%-0aL/Ui2ReLJXhO/4@_U8I
O"R_#;E1L6auDpTO12#I+#rLI,rf<n%D#(n3BYJE8\8LpKK2=X.Q%/a,J,upllZs$eMob%kIkE-9fY\R
\&%XL0#4O&F2@%Q=2M_fVn]CIot4qQ.`*LG4hMHEWNZgp@_-tJOYK?gL:hdke2fTPX#hakmCc%R`4>Ct
QT@Z#83J:_:ceeC)R8Wi/3=%uJiq[B<4<o/83LfLrO#0Z83OIB)*(5N:psIfBdgh\83L([9"\pn83OVp
><,5;83K'tW&@10G.@*'V)Lq.ff2_[,.Npt83QXKaeqZma/^CGZoCT>Yddq#83KL,83Ne3)SPT$fsc)d
h6ENVEk4h"U9=m4n\F^r]!PnWe[j5>gUl1L*4<$q0=;l]U,BqN.lWG:6ba[&f/%ucG-.[M#/3C7&[ZPe
j049G+hEadOgf_Icb\>@(,j+5OgDd+)8%Z7XKjUkaKFAW@(a06lScgBo"W1*m'Z_i1+R&q8@ngWHFPai
kHd(Q$+O1tS2?`m!;rP%qCJ3iT=jSH&\t`aTf%;,2R=J_"#VsP?95BrWPD]S[(p+f[(p+fMS)HjLGH!-
Bf&u(SN9ob5IX$5lbB:'9>.XF<kolh%Q6>^s"LXg9u37'YIj-`Sh9@b!;tim!Ba1=K"4]<8%M5SeN:sZ
8j#X-83IhPBKSgK7lP<G83KL,G!$O#?+3?f83MhjH)4%p83JUe83I_OMDTT@CcC*29g$:lXh2_483L(^
aL]JKD(eo!rOFX@Bt@-P:q;iJjfNd?;nd[aUcSIe.'cB,N45oMEA+m_0"EHt83KL,83L6?(;*1$GHn;3
YV7-6mQ5MQ83NZX!;om5P;kG,lFsG^UqIAUb;lo?M7YX]1p/bugUp.YWPIu7%(lT<lFm8rDS74(9JAuJ
SN9;)J[T)LZEU4B!;lipVRNkF#/UB<!;lipC9RXkGIKEA9u1q]!PL5'!;nRe>;Vm3Lc>o%.^IU=UV[td
RQ8;C<&Hcu^GU6mc+R7:5rO>&YHU4!?b&T9"ZG<tkH^:/E]>I+*^$5W[(IJC4/l&_LTQ`LLqW_r(pIDX
83Poo1H\2k]f\hK!P2Gs83N%sof>#l@l"r^83Kg1b-d]uHFtpla=_fl<kn_o#.g))l(nQg1:`Q-"LT(.
=#ZKuOYimpKJXaX4hk5Q0fl,AOu6IR#J(bb(pS\$-FYTUUbot=UH!'DG.g!s#.n*N't,j0f"Dg1?n(u`
83LHE#X.E7"['O^k.4)GUHCk(:c]4I<3n6`4?BAoFgNs1@]V%5l`h>8VSJNIQ`3KdNNA2LPe6t&9Y/J,
<'-I0lT@Np1HK\A_^9"UUHD.0'0X;j\@+pk83OOD.^aXc_)t7I`]I9]a!hKYYVRUe5s0J&i4MH7TKH&Z
7_Cdi3[uSkn@\LuGeLf',J&i>['DX)\\PP_jYH,8_)=hI`\jVSj=gKm?+Oo183O%:83J4ZI_&'5*%r$f
%)7&%d(PRV#f'$HI),p#HG*Ou!5(D0+i5tM5/,CZKu&SXmCGBpXh5U]]=i3s"MphFFM#l8,Js)dG-r($
h7>;I/hc.njL`&^iOe]lHb&Jp+gQj9)o4/?jJNL'?be/*\\PD_W5,RLB#3`He@`K.'ta[aTu*tH^VDtG
<]!X[4/RK_`\_k7'>IF!m4hnZkHjWgqmt+_"L&ND8$H8SD`VGh?p)7b7_9BtG;IILpGF)%fXd9RCH*?>
00N8rp,o<:N''WoC:X4(5X!j`M*-\V"/Oa383I2;r&,iYZ`$bX@5LG/gqVc)jdfJ[Qo'.1f!eC2Jfus0
83KC(A$&9bhDGa$RBikT83KL,hE7_r<&SPM83KL,HoX_\83J-,83Ql2/307ZT=cD[T=bBB=13dr83J-,
83L!9gcJe$83O8_+h=n_Lce3kTt4F8s"OI,83Mbg83NBH)(.s<V`^n;BYLUE(d1DQ83Kd0MS-hgM`[7b
6p+"'83J.ZgcJ%imk#kHANWLHkWHgE6a]HJ83J.XHa$%(83M_g5<MJ"h(gQE;Dh!.j#dVg$+se.83LW5
be6WS6nu]o'"stkRCid<PeDSjNO!321r5Hf&Mj'p@C8Wh6E3^?/MNhZgq2K%83KL,83Ka041n*Io!&9Y
UH9nf83KL,83IMI^bD$8,X"[]83O4=:,YX+83O1>S2*Vu83IYLlT@^$n0kJ&Dm0:&'fh>`f!l#D83K#$
"$B+;83Hr97QX.(VR'SjrB!P5Z8c5O$a=D+83N@r=>!--BfO^+JiD4?iO\A883KL,83P$V]Xn/,YI-na
auY_GJiG2A0K'G"#JZ*Q\M5nIIBukZG.5\c1,a;4cF'6$0/fXa\N*kTf=P?NE3"_t:98iR-,"H0EAH4U
0Khri83O7@F?2rU)7m7<Ilu1B83K!mKs*m)83N_,J%-g^,dKorJh6XI35F`6Gr.4c>F[%Jn@:;2V6`QL
iNOB2o<r<l1UDG?Fhs*HG.%LdqR`?0^q(&ifW2fq?bJn@C:X\\Fh-tScG;fW,JL1nEP<""_SGWUd_45G
%Cl;JW4ZQJKY0%Rm)%AeU:[59e\BYK`4r@gaM$0=S$_+aQ+Q%YY.,C_2SssOgU?skC:ZpF(;O@l%`%J=
N]Tcp83MSd!BNb7J$H4<ANWLH2*<WT`4&9#83Ql27'oKJ83Kj39KYj/"#4^V?9&?U83N+jZFV&983N]S
i4Tc2a0V>LI(l[2q7T\>qn,_/?FFO]WPIT*nM;T.75IItmBb/")`EmBV7M[I83KL,83K't=h@3f'sot^
,;9ldN\..g:TAKD`4j<ts0+\sO1.Wh9tQq+@kuZC#JHe=ZF7BS(9tZb'YrP0\@obm#/"H\kJ*1o`jS[V
%'TH3&@4h_4LcZF5/=A1^p]?8mCG'cU:oj):pa99H*UV]<Ogqg\[;%;T"pPp8i$@S:pY)F3l%]+:VL>E
@61JJD`N&';D_T3W4t,Gh)/KFEil[O.(@d'M)`O70X?Hj7lS[QBKY`CEkUg%F"j8rl4&faRCefo$Sqph
83LNHdl^/aoK,T,28$1V83IhQ&Ng.VJLi--83OaJcngtDI("JbDDolu>/5,<:9GA:">n(T6b*sgO1)q^''')

bicodon_usage['Homo sapiens'] = _(rb'''
@PeZXl8Rif0g3B8oskJn^cY[Z"Zdeg#!./oo/k2Z4uUGBfJsg3Qosdt0"bj[C9BG$HEW@;rjU"OOZ93l
)*J9f+Z_>@n2hCJ,JAId0g30169+a!(,YkG/3FY-:-5F;nh2CSiB%i:[_-?;D`^cT2`rfX6*u)$%CGpn
4$55\0g0J;/NkgOXXc.g0g.6SgH5$feZpnm0g.TZ4#AZT0g-+09KY$mDQk6G__I-2=#nL4.(NMA0g4AF
m(A.\MR@K:4hGniBY=ti)8#XG2mglDNk`02i&LbL*&fT8CTpYtV_gt*K=eWO0g.6S0g.3Q2RkJ)%l6d=
@luJ/0g4GWX$$#:$83M`rB)et0g48PR5H]^0g.ic.5inD0g42O!Bi/#K!SH>M&?4N-TV=;<4OD70g1\e
j?)9^0g.Z^e2]6HgpWq<P;rM&+ukuE3Ob&.0g3W7Z8jX&XYt,[?TY2JNOXg,0g.re0g-.2/%H]a"LKmH
M`XHgX>Ze63BE]g<P=t`P;aPcMmE,XT!29M5r^tenM<m!5<86o*'E+;&\S0,kd#TFGdhk+c+<_VlSIr]
0g1X]TfXtlGs!fEm_#2T0g-pIh`@l!>;]&70g3*/ZSc\\Bsb</5rd+EjM)p"ocj[G?7[]c3O*W`;B\Cg
fJ`pjQSf(1,;ud0LqZ_@(d*8Fgc01)*P(OH1GkQ&"g%2RZoNXsYrn(.cacn8n$a4EjWYGN*P4,9U,X!u
0g.3QPrpca:-:6o^U[<+=Zf59h`*eYng3$Kc9+!DXYmR9O>VbI8N*P#/ACU4A36NmbVp+bFgcWCi3`nP
QoZrb0g/c&\N2H.jfBji!^&2#0g/f%%Ce,U0g0S;%^IfP0g3B50g1RZ<\eVV;QWMNkrRV-!5&Or0g/=;
O1[NZn#?N'5J0:Uah9IB2nWk3U:6W+j1kDs1cTQi1,^jMdkti!ju6'sm'o>?0g.6S0g0D84Lm10bVD.<
Dn\NPgUuR\4hc*QTYRtL't]46QFJEZA&1CEB"M3\3Pa(I?*k`fk-f:e+hEcDikIpm'=<_6JAC*SW&>@)
oXWY\.4B,FdC:JZD7icX%_Igqn$Fmaj1dmkk;>rH6b6g>/%40E2SI,A*5I9@or\q<Y:8JA8AN<Y;80?J
H`0KEB"1sI?`adI'#:WV6nN\qE43TnYe4>S_6b&dA>qRMnMs`5ffYQ\BtA[S8h9hG`A)bK[^mWi3&pT9
Lc\3h>roqcXu\C$J@tnC0g0/0co;Rp`$mi/0g-U<Tdsh6j0a]G2`>b3]tT@`/iD@h68b>fHFBS(L+h%6
I67`r!BMqu0g1pbr46u40g1OY9fX[cgc,d(XunF%#r]+Pj#IH0_Dr_ue%OX!Za\5iS%,?-gpsSpq)"J;
pH/I=eiPTL@lou<=M-IP0g,V#+ZL2q(-&KY"$QWF`B(=d?n`HY4#m$j'Yh7>0g4/?Cc3%e-FgH62RlgL
,s3nF0g/Gsi&`YV)RQY-LcdCT0g2[!BsfZY[lf@)FVlhr0g-mEUH1+mLp2Ln.Q4XrT0/F?-G3)60g2BX
hRcH:h_btTBY-8aR(FQQS[iu)7PI-@hS;gn>;YZZ-TB=5[5)#Jq5D%fjLgm8gcR;S[liD+%_VHs:To=0
>Wcga0g0P<]KDZG@A.^'/j!r5[6%,C:G$?C0g-.0Y:u5(VEABNQoQra:Ue,#,Ifb=`\brP'>"`(j#\Bh
E&a7IME?,E:H#[C<kFJOA2NO2]s;gbg9oZq0K_9I`A/8gIkFt]fJHJ`&A?4Cb<%:&HoJJ[=1`K0ppbH*
mP`!<"LGj#>-,uRVSK+4UF@7q%(FKl7(O_S5-`3_QaHoN;Daju!A]6]DSK[@$FIgZhm8NV(;:?jA$EMQ
kWCR_K09,q\N.\m0"fIkd6-;K(HgnAI(*fGr]/(VDRnCWi46*JD6sJVQbh"M3k)*!iNsc7\@@hRqQu/>
K/\(_Bf!7Uj0(&Gh7s`2I5PlPaKRV4[C]>LcDuu3fssJ\%^`CE__M,!L;8?hb.E_L$+uY=VnZ?K(VFh%
+ursW]HsmBjYW)FEkho6oJ.,j4h;07)7_];1U*=TpaIu0]Xt\PO0[oYCr,GA2DlqqV54R*\\&!RbIkAD
7lrFg0g5"e&3DU0;R$co(d'N98iu5s<OX\G0g/u+*jdXb0g0nEBKZ2T8[%qO0ff"k0g/,^p:=os0g1N$
E4XLT5;`PPK=LJ3=M+gI<k:(D"IgpSHG2g%NB.W`h`!8QV_t#+QSt!hppsZi0g.6S0g45OI(D$qG-"=t
W]L;G0g.6Sbrd^DI'REJ0g-[Cj?/#UHo<]B0g5:or@frh0g5LtniZb2K<d3pMQdRI>WO:A^UT(L0g26V
,!=sL0g.6Sr&ZVr\gpH:FZ_BApc:o)TX7$B0g4PQiA`PTYqUhnUcXAp7C+^30g-dF0g.6S?apk6:a7\X
/iq^dYr!7U5;KFM$G_E>V)9j70ssNZS@KWJ>;%Ze"tEP3O#heRTfg1Pot3"B>WBG3?8@6dUq4s[aYZ:8
0g0)1O#o'Z/3LO,CV2Ab0g,b(Grk7O*AjNO0g1g`M)bYss"Y'G3]XN)ZG/jj<Akl#r\sR.Ts;`s2_F5Q
-);8-:TVMpau0'tKYAK_dPk+/^nj`-;6q[Vh(cPraLY]e7CBWRYd>pkA&*,mI_F@Hc+Ls.lFp-/S@Rmr
p,>Z&)DUS=,qcGO/&72o:cVB2#q&cUGdsrd^,%.Chm"95PJ,`s,J)L>%`3b-2nH<*-b*lk@D;fQcG/tQ
]K.c10g4&K0g5FsUGu[E$9^+,0g.i`r3A%?0g,V"VQhj=0g0nELcdCT*&h=hYqdpn7lu@0E4b'e0g-,M
"M#U3auA+]hm?KG$FkDji3UNcJi2o*'YV[B3'?B7)k\oKgb7AA7l-PlJ[hm20g.6S0g.<SX1L)L&$ET,
DEBR90g4b`>s'i).k[naeN>QL0g5@ndPEU@0g3T>.A/CY0g1+L.m,OL0-_i,b,>n43'2,f-bAn-0g2#!
TfFhj0g-[BdPrsEmBfDF<B2cs"?9[E(qEd,0g,jq5U%pGUT\Z"+?2qQhmsO_0g.6S0g,q.YIj]pr3e=C
,<0]q/i>UJW&9,U`kAuF4"V;[4gu]F`4/@ESXa^W`2FG2V)rTUM*()aC:nRLpoXS&K.n^],.rW:r%_rj
0g2<p7m&Lh%6Q@._muF&0g3]BW]R.?cRdL(0g5:lQ7)enCq$`2.Q!#8>/+o4P,a/=Gd<a3DRdA>B<c&1
'K/cH5res-,</^Y,JCZF.QSQO6T</kXLN/Xl8;*^A@5`(2ED"%OZ`7t!k!88^pXHW4K]R6S%BH@ZoRNZ
Tfd9Vs#`#!904jk41^>3UcaMseiUB$8@2JNW]D4YOh%_N5Ih%ZkUikhk.Y(Wlnl>VD`7&:+M-#RDml`-
S2rAf0g/)gFZM6?/hC6eauV7?0g0Y<)n@[d0g02/kd3'-0g-aAD*0($2)GP!O"+*g/3H2.gUn^g0g18u
34r6Iei'A9%D9M3V7@8P@(H:n+Y7WH!PpM%0Jj$MX0aTEqQU)`"YHQ15e/0o0g.6S0g20i0t]5(r\De[
[(b/*4M9[e?G;N6b.g<Y9"gh/[^R<mk.rO^?+ajcX2(U9;lDmnY-_IkH*W"0ftTARMR.`HrP5GD2DtfT
W4UZd-RsJR;7u-J=1g<"`46O6Z*R'8EP^YIUpU-94i+>5hnJ6b28@GK35?ZNY.1aH1pgW&9>OoG]YCbb
N%?foG-b[5)@orP$bqt$(pr&0q7&8nNk48Znu8=b8Zo6X9KOI\0g48PcF4HM[4H7&?T,=$-b;f&8itZ[
!^%Vg0g1mdaZ:;&lF>D,0g3lGniROGY,l.n0g/Go5-tGPA2QP28N"^MXM0$@AMIsP9K%kdmBdBa2Dd<P
lEm@q/[YYaodu]@>eaLC`%gd:1pXPA5e9+`Bf-_Y5.fl4[j?,QI^GTQe\?16@_LX2R_)#&(r%T5Dm\fA
#;SA"O#H5[ZRaWc#eg<jUGoYBPr0toS?f+NDEI,8'Y$!)CV\c38@[WepV9D/'t6TBS[J1$2nm2=)nl`c
+Lg,^(cXRd'fCD#_Pk;X+LNpe,r\OLK>#Vo-p6@cS@UF<OZS^bo:J`7i4*g/IC^+Q"#gn+[Cs",Ps!C'
,JcOQGI@F`s1Z9%oX].Y5e\'k9sf#WID@hJ,s!cq5.iU5<Oq*KhC9I,PI>Ne!'2ht0g.-K_7hWe9"KU2
L+cC`6TQ]t@Q3[7HaVt3ZnfQ]3&sHuR(7;uFuhXXS%&2U0g/Vt\i)9+![eU?X1/6l#!8Khah3Wk0g5-<
V_iBU0g.l^#<4G$Og-Z#S223L4Ym>I,IIb:0g-J_1VW]>3kJk16FW11HG7>)M_KI`XtDN@o"H*>LqFt?
be+4qZFqa$1V@J5N5=kk1VL-,I(kcV5/6*gD7ZCO1VTQdPd,EPJ@Mem@DHik%)16(P.UG#o=bREDR=Gs
]t!sE[^2%&&\2.%OM>tIhlA(_k:d+JQFM2r/j.+SKYGF4*ku0ll*ed@MnhcQPeFW>.Cj!$;8/X/LV-]q
NjpLGUpotN2RqANa2%M]J%,Nlhn$h=6+o=m412N-D7rWTVmo^;jh&7>!5`Zc:qcqEb.J_0-c)%_hn9]=
W4B@K<4hh6(qlEP(;jOn+1uI(V7fa@H,+R<e%>[r_RF!ec+<GUdCf:fMS]S2e[Hm=9"X],UVWP9'#?-2
dBG>gei:K+,<3(n%CE]+&2*Q:FZ*biQanh6;*;!@U:b;"mkas?nu''ud^sRsp9_i<:c2=dOhXr*CGnPm
PefGqZ+k1klG,Ts6c*3G+2EE>>eSq.I_q#W$,$5PhmG1%G:a1`T/;Kg]XmJh0g.6S4?V[cT"d!C9>$rX
-oho'0g/Ar;E?NqL*hp@W]2^r,Wt$FC:Li70g1"EUUW$A0g1(HM)I(OT<p"-6*Mk$0g-J^m_#;N0g2_M
ju+qW0g2-jKJbJI$au3X+?)#<\2f6lYe!1W0g/4<bqa,u:c(O"4uPhlBt,!?]KGmM0g0kF7_e"B#.kF*
"h8?Vn%'GmDRH%EEPVSucaib\j1H;@6G.cWH*MUn4Lts&oILD/dP;oL@DCt`;m5T"['4GZahE&4<O=Zr
Cq!*J#.p,$6Fk@Nf"o>6)^8Fm,.EQA41urP/@Bu<A[ND_+hUB)(GJc?)SiL8mP=aFN%2Cnpq>4U,J<1k
SiL"9rAZMpS30M+ft,9d0g2g%BKCo0_`A8h[lbcr;_T:Q"usR_A2q=T&&&N59sH=\.]Q.O#.u_%SLo/o
-TmhYbrILAGWG:S&\d![#sE/fFuoIZ-npW6F?7r2Ou^?=#I#pG$T=e8rOsI9+Z^)jLH@4RQ+<&<;n4VG
EB>m<0g0eD@luJ/?ndX&0g.6SZ9/pa(:5eZ0g3Q<n1ud^0g-C8Bf[t3B!]K=rA-MrKKG[0&A*ZV0g0W[
pUm`8@O:0J@D(AKBY<uLHb5"hIB2eK&&?#iV`*AE`u-TphkgiFh_U0Ni4'(Q0g.6S0g2R"`OR]d%PS5P
dlIIk0g4_\904jkr[h54KKLtP"[/nHM(CAE0g1+M@&u(G0g4YZU,t(m,bDn8Y:K`9FZf3"4hCnR0g/1=
L,aWE0g.c_j>SeV%C;0WGW.??2`b%t%(V<R0g1Jt*&tPm&[+&RPr5Bu%(]_(0g//i0g1%JCq]F&B=YQ8
D`Y0]h_Rqeg,3k)FM<AcaYi%d)n7Q.Z`u2;@5Vd[\1C01=uaM]E&^WO;80:rdBN#IQ*W!MCqOu"$njN@
0g/r-F?D9@0KV!PkdoA.0g5.k2*@s$mOt.l0g-12.PMJp6FWaPR578d!5Lr^`%e-ps0%VCCpt]MQ)CH>
6SO@s3A,P8(nhDKYJ64,f/GOrnfN+a&%ofl+Js^s,eC-75Vc=o*BDJ+ZFd_/YI^%3I'oT[>/#m,N2U6u
Ps"q**Bc,?2`b2+"M,U8DERhYofKlHUprh#T/e7'A?0^Z,e;edos*kfS%fXm7B^(0A[IE'8%ftS*k[[m
G;q<?0g2'f@6-,+DBpVi\2l?-]K@2oC:Q&^0g48N?+;UP0g,q*jub@]M`@n&)_gG90g0ikpUisO0g0-X
c+?G(^c:;_!PGTqBXp[FGe$d6.5haM^qd[n^G^YXT.hu_bUZXR?o9GslEp1C0g.6S0g0)/B"Ti]aY#S7
^VDS>`kFIKJACro2o1lsNPC@bot5Xe9Ys!/d_2]s,/QIP.D"<K9"YWjGe"d)Kttd><OVP8%)NFd=fisc
l+C-(B.g0p#e[f,%^m1b7Cpl)<@k&\42LL$.CDse`k]:$=MRhK8\eH@R)&7+Zb%*g!5,eSq80n\(;ZKS
BXX8<age^_/$ZmuSA;256+>1QBtUjc_n<gs!4=AbRCRZ&m5D[:5WbJs_R]A%EO>eU#;Bc%PJ-h&i&#Mb
]fZ$P0g2m+G<.HA#.\J20g.!LniX*:'t"-%0g36.ijkD[=M/6&MCu7mCVQ,mZ+'tG`3?MINOqq=MR/O(
T020rpGt#lE]NGD`4Q.0ofU#E%67<A4JlsP%m/]/7\EC5VE(n>#<2-29>4(YHEu83"L21AdCa5'Ag7#W
,X(NW0g4ea%6>@h8%ej_,!E%j1HINV&MsbR1d%?iNO92%mC'th#e%d]]tf<-s"sGZb,f9aVn1Zg$bN5p
BKC<!b<5JX,<7JAr3AgPjZ5+Z4Zg25hRG:'0g-=5Nj(6$0g.f^)EKT9SZogi*&]N7l9#;#9>!8F0g.V#
l+MVB!&_[)ICs>SA%2`TBt9-aats%,PJ<)6d5nA@jY&>OFYFaqi%Rti*4s9O0g.6S0g.ia"2$?O;m/JI
,<S(M0g5+eX>_jpY.<@BJiLG#69%NFI(N?73B=7D5I`%!*'?`n!'#?gPI9.*\$eLXV`$6?I_@,+@68G<
qDL&kofRdc=>_fr!4UiG#rFA"Yd@Od#J#XN5s0WGK"GI"J[fa2e[aGAl+`"]e2%oP`j]3aDnk\Lgq5GO
FgC5?Bt\YudC:1)NPTMA;7LSXhn99.@_LF(J%1*=ZFQ/M-nZ2^E[l5hi4`\Z>.@bH7(Jo#HG7t@_Qi(0
g,Eq2e2:SoSMCU7g:]X0)EX6I-TS(b)R-;'0g1+K?F/"a8%@n:GIY8mLr!Z*A@BjsK":Wb<4m[c<k/mD
Wht][?+')ZQ*?pkB#*!%4"YNcg:!rk28$H3n?D2dX1@,p<jMWUgp>#2B>OMNe[k"Xo!jan42C6u-G6h$
Up$N'._2[cfXX#R@DY^K['u"+3P7>b,efe`mCQZ;qmqWmC:f*R$FE1/f>-Q#Yd2ch1:6bZ"27sL+MO@&
kUO8.7Q>TQ$op%*?F\]LH8ud)%lrf4c+#Jk?p+$?8\-93Pr[2N1,N)m.(]XB^+!eV]/e6F(;2#n@6#%3
N5;4%E50W3Do&3^9>YGZD83-aM7duH)8ZQk:qSa'hmLZjB=dFibqqXIA%YZ!W]Ed8kW9#1U:i9E._-ld
C-"(40g-dFD`\LnZ*UMmkW;X(`]Va-q6l/@0g3lCGIB4h0g-(.F?)'=%^r&meh)eB0g3IR#.uB?0g2qR
c8dUB0g-XA8N&:dgpe=bH8mWBi&T^L'"9&E0g3aQENV#ZL*4`&cT!XB-b54!0g.6S0g1jc\%KO=oX89m
fs9MA8@k'CG-9N*V8.,IX0AS6!P1\/?+V/eEO(9GI'g7?.Q3\U&3*K>gV/(rf/0Y3F0.^8b.W_D1pQAT
:p!$kB"8O.\@.g6bJC6`LGsE/WhnUG=M#3VEj5SPc)`-JDS!hK9/gQD<54)J'=C[c6nY,iijje#Bt#ZQ
Zb2J\7CO6mr\>!;?bn)%oWP!nWO^<fA\'1n*&FBIW%nB.;CI=7AMe89UqN#*!;lipR_QYV8\AE?%QkE8
/?t/J<&0$9rjrrXH,G-BB>4,SRD:c"Wk/9/9!GY7%)AmT"2T^PoY7?;!;pB@LGc.ZGG&WbHbF:*?auZ7
@6?8-0g/`&2EW]WNAf3E0g.6S&3Si1::;l?0g5Fp^*PKs0g20j0g-:8J2270<]8u"YrX8;!P@/E0g4$n
,.p;q\Kdu]Nk*7hagtolK"4Z2<NjrbID0'omQ#j2k9McFCpa1&Gq\eLQFY9i0g.6S0g/#gpU`.C'X7Ns
k:gp:;Q/A37QbrY"iKr>@C:?l_S"$mm^Q-'q(\[%m^P0_G-ShBi4jK/Pe9N#gVX93jMKZhN'!mcgp*$S
/?ql)pp>IbjL'9Nh8%j^/[f`6Zah6qLVS\\Ou4i.gq(D:WPSZ5Ge7(n!;smQ]t(S^)`2]MlEe=B?Gd_o
n2V^Ms#%)Be2>B(m_)%H=Z+('hm)"E2n48e9/W.s7^=j/WArHe>!/03_n7`eo<NqTLpM35Q+bVU,-L:A
0g4qeg,h#Pg,q)Qn@?Y'0g/o,`]ETK/i/)>0g.'JJ?ITc$G9+o+Z&%2WP;Ln1qC3&N$p]k\%&e)R^@E'
?T>PM,W;DX(H.8[=21.X;EC8WdPPLDjgbQ--a)43.^g<LP;IP=a>i69&\Vd8'>"O]0"6&;?+ih@=YH&N
0g1mb[QL]T,!=L?W4Gtk`]UUg=uq?pk-9E@5s!1B`3^8b@'Kkb%^6JNCqq>KYUIi-hOq$[[(7NfB"8C2
]fSPCmQBSjhE#X=V'CCJO?@eL%6^gMH+"AL0g1ITe?k2sXursJSNEW*[3S4%AMiU1+?\\n@Cue%W'#",
pUp:/VlGom&\Sa`h7XH71V<@fFLFuZDSRd7(bb'dC,.M,i&<e[n1n*+9tQfM0g3<70g.0N!4jmJMDCDW
F2+0Yq7XVY^VA42@)9Um@_G(C8\@("4i/8V&&.JIeA76ZHFn:72S>!XDnZmu4i)W]Qb9'/XhkI[FLCSQ
Uq>?gAZ/eD*P6kZ7(i0%fX`T7-FDUBikSF)mB"pS/AcqOHGC?3J&'sTN5<rW1VN\!QFhX\I_t$WEPNU/
"uUh96mQS)8Mt!.!l)f2ZnEoA,HbpqDn>>FBW)`OOJl)74ZZ7rMELnu+1jHo-o#2>K/I;N_7GK.`]-/_
m6%:-iB2fVSNJViFLfj_0g1gaLcfoB$E7Jo0g0V<L,1A<&#lQb.lEVJGJ=AA5;:]qa#$C@,.GoVVC<*:
0g.6S/N>@D0g,\'Yq#'$0g.6SLHBH0"ui)80g.6S0g.6SEBG4%0g2!g^b79%cb?Bhr42a9*]5Z8]fZua
0g2ZoM*!FTXunF%l80VF$p:(B0g.!>RBuiQ0g5<1[6$*+HaH=)U9N@[Ge:u&0g.6S0g4tf)6>PU;`kUD
,<R\D0g.9S(-F<7$o*T!LHI:S0g052HaPRk0g-=6U89S-0g4YZ]K7i2cn;jjM_siaX?:X.Vn:;80g0,#
jLm:TB:_K'Z+\+.ah/P*D7uXB6+!B#Wkb4:-SZ4Jos?G:_6::-GV\;@'>+r80g.6S0g5(gLV#9(*3L#<
VE<'c0g.6S0g.0QL+n`O00M$Q0g1RY3ArTT0g3`CHnmE>0g3cC0g-pJ(TF5nCpRG*R5bng'=ke50g1.9
Z9'd(0g20lrAlYrijAtP'0J!4auFu4$F#^R0g1gYZn='rcSf5peMu;DppkE*0g.6S0g2<pA@o32<44ME
TK:L\VE"E668j'H*l"O0?o+1WG-E[,)R`$T.5rV3-+.8AlS_3iX>q+XbIkYPM(]pSX-ukqICpi5LbsOe
0g.6S'Ks/mRQ</dB=\d>EBMi80g3H6'!ULX0g0;2Q+2/tCpb'93\>Y1$,Ah`SM1Sa6R)E7I^s>Q+L+*i
pT+n4'=OGkMm:jFJAHT@K=#^4?b7bt(:qMus/du`!PL_14M"1p[(,#,*l<lGR(]`>;80-HI__5aS%Yr<
?aoF8C:l%)9"_LD_8=L1@(Tj^W4s%]XM:UIW4fmY3jmMK=Lo$EOgj#UDo"H?3O6W:;n5Z5aM/k2d_A)T
7QW=f0g0bBd5`pE*4"*TnN8NhD`hYnQaSV30g3oEPcul*0g/GrK01kOo.3g&G<+>=0g5"_(V:)80g2nL
G.p_[^U8F$42)Q4KYCF!VS.Mbk-f'>T>90k%Q(<&E@in.@2sPR0/f1[fXf*`0g.6S0g-76d^h.rCTqP7
"#96ur\$Pt%]Q52U:t0CcE<eJ-+,P;(;"7i0JX-FYe5Oq;RT]:2mA[ZZ+hfpd(PRT'YF@YJA3bO[^@Tu
<ieBfbHUUq4h'+OAAA>UbdM2q&\>uo0"mUa"gQCcSudgV27^#mK!][-2S_&KPr0#\0sO]_,/=r*-bdO(
LH6/0>rf;R<&E>alb@$h"?<oud4!);-+5Y1*B4ute?CVa$okOQI69qYF1iPVRk_sm,c^OGm(+@IhD1=t
0g-sJP<:Q_,WmeE*k]9N0g4DU'0Nle4Y^S/0g-dB*An'YB=Y?0[5RY6*l,6FQnAED+>q_-"hF=_W3n-5''')

bicodon_usage['Mus musculus'] = _(rb'''
?FAEF#rUg(e2s9`J@SfC>s!BnZ8egBFY97G'fu%J5d34//NEPc#W`PYMS/gI'Xb-O<3`"**4nMAau8(_
HTUFQ"?K:?ANN+>RCmN$>!9_bPW>$h*%0K"brZ7i_`A>k'K!?\%5p('%)*64@lnZl%6CIN_Rl[)A\/@3
=Z]eM>!;%/>!5MA@kd./>!6%P6p-,_=L;6p>!9PZa"gg]>!8`D,!B*mcEU>3^,'%SJiU0B/@kC4>!;1"
XLJS2e2-g.FLZ?Fo"D*5fX3R`FKoGic+YX80K9?NKfE7!dB8it5rAO"6+_A">!6%P>!3!OI^rWF$ShK=
^cP^_>!7['n2sl;/2(Nq#!H-Q>!:b(r?PQ0>!5&1#W,^J>!9tg>!58:SZjA&>qg.UN]G1hBt1Z1>!5?[
:-2WB>!3BYbW8oj9X[JS$TduDJN7d10XnDK>!3WW4$$P.eMddr;EJ5J0t8l!>!:7q>!6%P?FsB(X0qR^
W]->&5W#o*8Mr^eftD,S#oa5\OgmZd41Z4[:GND7(9ha9O#F3u-9?`;mC_[EICNXn6+9h+KY5sE:G6(`
>!6%P)*Qe;p,cG@6+_(u>!3E[@68Zme=mpE>!5)0:U*PN-+PBYAZbU'6bjHo2Rsp<0"$MAVRdBsJ[Q.K
8hsj5*]A@%W%bn>p:Vh-RQKX_TfG?=5e@W=&2@b*1UKe;ju_`eT0+>\EO`D<Ek'&p)PsRI0>"9jGWP<%
:HVfD>!;@;WB49Hd'sQJ4?YJ_UcQUVS[0e&M`fiMLGo&f6o)`X>r@d%bIr3]<]TBL-TLcJ&\Blm"h72a
krDp1>!4Ju"$BaM#-bg&G<B%l>!76nQa^-]>!61OkcS)P>!3$M>!896Hm(4,[ka.,kW1B,!P?]:>!:iO
LV7i;-*ggg1;":.+2>:tQFM@JaL;Vl2SdJFSMcYFZo;/OF#[YiYrL/m5.Zn:>!6%P>!4Auh76]P.5b]t
B>+tks1<Wl`k?o9#f590;nCJk,.Ph11r5EjCV/]CEkhga-+9,PM6rkX`Ooll*5E<$5eL=:=MQ#kJMB[0
f=BJ;'.GNB'"`"a'#&k+J@LK@,IWKBV8(Hi=Y:2u:V?S7kdRn2+hRoh1;Kp%/$nfUfr0V8/AQ,58\Xc,
't8e(8%2C+@'eOp+M_'fTs@Y/?+<Y@4han+)R`\W9XS(d\N5d2d6(/a_72Kf_(9'$lo$Q/27lA`ANI6,
oJjTH$T^[95<0TC7D/4Q>!:=rniHA$e??JD>!8E3OuIMBbHl2s`A;?fA%o!&:c):TXY@(-1qN*2]s'IK
N&cMQ1c`Q<69W%E2Ref2>!3*RhE"Y!`Acd;loWf]BJNaS&NlaLN]`@aXh(5h:q)Ut1pCc.d($82&3:aU
5<W%1>!6%PA3=$Y$+O;(>!;I>g,^uKbVPMG>!7m,?ohCO'K8Q@VD]n^9>5^3>!98KI5o2'RC^3ji3u08
6p"R8>!;mHJim4">c*iK%6[lX4$?n0_73Z3jua/6#bkKc>!4,l2*<l^bd,,KJ2dBf;EU/B\[oR9>!6XN
&%h-RT/GuE0tIfOa1NY+Ydp&W338[^cG1:.J?OX?Xt:q_gFhMH0s<Sr\%SdsP<<#3S32$Y'tfSi.\sj?
Si^+=>!:P"8j-?@8up9#D`f%'i]M$<au%I->!8E;FX@ec>!;UAlTENVNij6_c*]D[C,L7I0"4Y8=ZpaF
>WJiID*7PQ+ZV2;"M2T5Yr*gho;T>ROLB0i5<LDHX#/Tk3%d]T_`.cZ(qcJ#&j48nTK)3m1qR'Rh6_Ph
@O#A:Za:s[A$>'ug:q+&&[QhqG.:8Z;n]ZKbd1N^@_'W>"#]3lW&/-F.D>gCF13p3G-MRi'u":h/1u(T
i&b+*j?1=A$T\#FNOnXA)EdgX3]rH`?+F2sa?$)tlaV-s6*sb#?+Fm`K>AM6-b0DkC:AMsHFkOT:Uobi
W3?c?2'?nE#e9Q=YeUXW7kG1]=LEpq'YY^'bd<)8hRl=g:q)(c)k`e49u&-\O1b%u::s`E2o%ntKY(I&
3B9JdLGu=l3\g:_0u'YBfeC:L^pku*+1uR(UT]<\FL.gSD7KALqm]tCikW(5"?!X!UTp)nB>6(/BYM_E
fK*2!>!7U$oK-5>%CC(8;*8#F,<T?p$+O/%>!:7n0!\YD>!5561d+8j]W>:"=Zl%5>!4r,]=A\:>!6Gg
UU2a8.61*R1UO>Fo"98pG-tC/`[p,ZA\Ffk$ooTEWARjB82r:bK/hLGVn49;>!6%P>!6R^cam:C?7S3#
BK96Z>!4u1gcSb'cQuRR>!4>u5<TN=@k_(L>!3cds!Lu5>!8ZCk</Z)*?SHJ-`e7GME,jf6b.n&>!5cc
NB:<,>!;=:Ouli1'ef8C&Nj5[C-(T=l*HO2>!:n"\2RSS[P\.LRQJAKhmZcP>!6%P>!5\FS%CaFL94WB
!]=Gm+t_]U,IEB<E59B!c6]I!41R&Ulb"%C`Nf0B:UMc7i](F/T0"Pa0YMZm0K);$lS*[m?G$ZOX>?i^
8Ng6?>!5A=kW;s2a1=Q">!2pM5W`:4+"`g?>!8?775n:)1q)U,#r<\]>eoegj#=BJQS;l![C?Z#V6b>$
U:I\5A@4-?U+]<EGeO]mZS>F`$D'Vo`ORD(euN,cj1Mt1q6oFmDm_7.CqrBFhnE1+$b]i\B>@N\kIHJ`
`\aMM6SqOtr@hM7WkO]P,!#rhNAEpU'=s:5A2^-irOB)AK"V5qgq80N+Mnf*8\'#U`jhJ;Y/+kb"MlY"
iAt.*>!9_`>!:b*i&:En-TtWr>!5P?Ks"TB>!76n6*XTV>!:+k>!:@tmkca^YVsBZOue+8jgbCO>!6Z)
\?m&.S2jcXjK<#Q"hIC&DQI)%O>EB8HbJ/^n2p'KeY651^p51H9eom2b.-Uh>!6%P>!868Lq6bQ;(s1U
^,]@[>!4])+?`mk">&=ii]LC->!4#jB.mFO>!8!/J?W3?>!::p.6TpZlE"/PHE0t(i&LqIWjjH:>!7bC
_Dtd_>!9V^5<;t27^js3/NR&u1,r>p\$p97>!6UQ==dW="#=+Dj#=,$Z+HVg>!2sN>!6%PQFpBa3k-V%
Ubn#_N\Iso+u\_f*53+GHaH5OK",X.U:NChHEVk&(pnoU\2p`L,s.>Obd\EN4L*5>4tc?8a1Uf<G;a$<
#!H-Q>!98UJNR+![CG!S_`V*cW]RCE`io;#>!70iCpeLH'"J`7oWSQNVS7+*O0JDa\$t.uO1T0eNj[b(
O=.CpJN:.u.l^6\:qZle$Tc-R>r`\!pq#n$>;bBGd'C_T\i`PF_)rMr27A`3qR2Hh`%raP!kR)>=ZdD&
/Ncoo>!6%PeN6qt.CrPBj#h`PPWN&-)7[O.K/t<P2Rl:9WjJ3PC+f]H+26\j2E/#nKf=E4!k[,A'"&W;
D)ti`>!5D;$9VKTbUA3+X#jKJ>!:n*ICNHD>!2jGiNQKK>!;I<q`C.G0![W#Ou)hh$p-th"2$fV1-GuM
ot2cU\h`id9Y>t]Zb0&F(V.ep^9FuX+2OM\7]I6>\>`Xp>r<!PIPI'H%D(^Z>!6%P>!9thj1/>V]/Rno
@D5mX't_i+LV6Krl+iIqg:D488[m'\Qbcn?g:FK&DSU@rPd!`kJ[\pdj1'3>&&8sl3kD6)IDFOG2`56^
.D0c0!OAT4@D"4t)8=5(=h0$f9Xoeh,f.F4s0^^ua2!G<7_NZMhn<(%?GM3+o""+rb-=sW1Vn"?4MCp0
Qa(k8bcWk.fe"'uQG-Y)Og;!r^p`C:4hPg@a"6_eo;P_Q2E`]U>!8K>3j_[G*Auu]]fL,BN49W_>!73g
!BN,%,!DV^5W_V%:V#1A>!2mL&Np1VIC+kk>!5kAW3udiiNkp3dP]i?R(\M>FYopO/NBI`CpmS0Gr@65
>e)Vn]<l%P+u?<qg:e3,GV[K&+>[4Va1:Uo-o59`#J20=$8F+`n>u^GD8%8L=1qqPf=@fnKtS53#c"uC
j>PjTQo\n?FZ%?'g:QT-'KT)QL,aK51UH=(HT^LH_n>-4oY#pem^Y3`"i,u&W2fKsMm0h&+hr0-J\>!i
`OMg&Lc29@3B7F.7^?ST$ntjJVE##ANkAOYr&SaNFh'b#ffNt0o/2.XBXt'!0"FD1:c4TL>.Q4D>!4IG
m(e=egphXD$,5c2(;*&Kg:^7c?F\7o0u<Om@5CEh)S909gpKj;h__N!f!Xa%?oV=Q>!45qf=b?N@CJWa
&hZO3of620q`0-e9Xs(=75lta5s()``O=&Q$9AAJ=gnl("[/J;#Wu9R5,SfO0Y$d7'KJ:d@_$D9q`HL>
WAmU7<]sYHC,ideagY),Si)9c)R'K&'"(t(E'/$F&A0>KXLtR@Y-2%f&\les>UrgX^G06'k.Q0tR^sKC
Y.fV'R(hIk2S>6`(;c6I+hg"JpUi5oA\`c*KtK:UMnYl7H*Uhce?C%"fY0j"D8"o>T"8@E_nOm97j\_Y
"h<560eN@2OL*+gp:XiZ&hZj<3AVeXkIG4^@6B:M@DCL'^V9$DkdW(<<5<@OL:q30bddGYqS*fO/\H_F
\%H@_a1)qg^US$h.)9f58@YJ,;7Ub[0#-G[OLM@)!PTP_N3sD4[(<$D+Mm3M_S&m]lFA7WV83DPNkC._
2S,$]4h3D[D7mEjZb\<-Fh5H$8%^+]P/)mgUUq>XGIfK@#eBuJ[_33b@DWkpFK&0Ngq#DUB#;3ps1fA_
6*qat]JuKC9f`G@6*Wp?kqob0Q8j(J%(]V*]KEhd5eNRFAi(bh68Gton@KMoO"9@kX#@AqW4nY,h_uFc
[_[[3M8',,KYU<q=Mh2Ts1YDD_7YZ?"i>#gkI^,s5d4ET]sM--X>@%@0>((@8Ng6?8N[tT'Ydg72nGM=
$9)-O>!3W`h)ee'pSd::]fTC\>!8-2,.Ndq>!8`>0tCIN>!5M=/im0!`3a>CLT-1n><JU`be'/u>!3M,
3&k))>!4E!aZ*He>I_^8m5\?5Ou\7SqmHhh>!65t#;C]kpFmRJM)VS"'Y-n!>!4c,>!;XC^qL4:Cq/C^
cFZBN5eH<gkI5`E)SdK*d('Lpf=\K%,/0)I0t/pJKY):Z82-Viq_X6_m(J!1)_sC`SMR:VAA3W+<ic\A
0Y/C9d^ksV_R[(_B#26hI]2J6!4#b:_7`FN,d8r6?a\.a"MJRu`NjkD%`!NNf<@oO`N_`\qn?:<jLchI
Zmb<&3]@I0N]L?'4M1,BiB-utYW:W#-8L<:C-!1lH*d'%8N,Wh=uWQ@@(kb^j0afQ?DS%Alb!8/#r-k<
l8nDs,!/Xb:-+:qkdtLi1HdHU"$Crk*J%TWnN0Q*ml0Di=g>1mbci$7ikAnXL,gYBKfWC#TtRNf^:[`5
[5qJS>!8<8"$KgN$8p<p>!6%P#sADQOKr%Q>!9>Ul7#n">!8?95Wi458[0U*+#^;^?98+gm^],Q>!4\[
Hb3+U(,/%`S%HY@e%I*=@(G#DFL;=c"2IL<6o#mu=0Gdj!]'F11,A2Ve[S%.>!6%P>!528T"/#f-o1]^
F?*Mf>!;O>H9>@oY9fSt]KB@\>!5M>gTXjE>!8]CWNB>e>!9MZei[,!=K^^IUbC1WVE666e@DtA>!9L+
&ij,Y>!9M[5WN"26aQkVg,N8!p,NpJGdk:D>!:i<4uHM,-8hV]k;<`1Nk#c`>!899>!5)5J\>5MQ+6<G
A2VUdBIo]/75Q#?6,&@2frif6.(LY8]t*5V/i(0td^74URPjdn;E2-Fc+KT.B"%0<9!i$=L;!8f-o"9$
q)hhD>!7*m-TYEo4Lte]e3$nt3]qOFS$)WL>!7g'27C4V-b8.o(q$0=HG<uJX11!nCU?X:#J:'q#.?WP
J$n2Yf-joYY-=P,QbGepHoL<!ZRqcX@D,^R-aLCr1qMm168j$Dc8eBU0=bFNm(;Vp1pa*n1;6f$`&']j
?TX-->!6ac1ch0i5e3dSKKBB#^,iqbQF^&(,<.?cbI[JSm(%2A_mD$IVnPMObH\jlqm"MVUqU*E0>(hu
0fW?">!5P?bWAukH`Vl\8NU*=>!6^_'tIL2>!;=6*4T08>!61Q=$95>#<#aKM)E=6]0(VM(qafE>!3A'
b.KG]2)TfmBY0E^d_+nVLUmjG_m&jIo"ZK^%4-&0[Ad=m<@*eiTf")X3k"K;>!6%P>!6I[kdjq\/2k+$
otXJ?gV#5TTYDM]@DQ0`1VEe&1q]X"9>XE=qn5_>Y/+SXZ+@-P"hG[)9tPqbM84bSA%Fb<S\`7W,dWTJ
G.ffCBsF2>E4jW$i46_9"1n[^+1V9^GJTHVUq!#3OMY)3M8;EiKti#J42Hffe\!iRf"-RK,/R!dK"sI^
,e4YupU9n+J?NsqQG4fS]XCeNKXr&6>J;VtFL2FcY.5rB-ot?eI6>J1TsYRtL9OLZ`\s?u]Y*R8p,Q9a
6onL7-Tu*)f/d(u(V'K-WB=?Ii&kX4'=TAK>!8*#H+;0UlFQ%.!Z4Ec<5+ANS$BaL$)e@c>eF)n_6IK%
b;iWdV)i`]i]2NKK=eTN<B]+qa?"W$TXXSL\iCih-`n(C`B*':]fKXb6b@n2;R)juYVEi%5J0"_N\j86
8N^0>>!5nKLHA[&2Rtq4'g4-3/NO\.,I%80ZocJiB!tC?j0])s+1Zp/5/9=h]J4!,ZE>ghZ+Nu8`jn2g
_Dtd_=Zsbb&3F&Y::3SQH9>@o`]R]jjg\JW>!864_QR-+>!8N>2*=)dD66u)5<2n1niVadrjhb`>!4Sp
A%hTCS1Wg4Fh?Eb9Y,GWLq&F*2lo?V*PVW[N&^4:T!VZaVDXApnM=*+/\C.*>!6%P>!5J?UUaPk*ATH4
WB4*B>!9haHTAl&-+_D\CHARSqDg[J&\O,[1HN+KS%-a#>!))K,s-'.rNf0[n$MaF;Dq@]L:j<6BfdrW
5rQ/6*^!+UkVl!o>.EHNRkdJr\@P']Dn7)O=$#uU=M!M!,e'qfh718,*PfLtNM&MI+1UID;nb9%WOq/t
BsTD!WP+\0bI!T_V8,j73OiJ/OM*<\N4u*tl+!Y%Cq;\bSM?S8p,+lkB"_>/CUR0J!46:IWP4S)I4QGM
6o595.Q(Kk\i(lt_RrH%?ohIS=ZMU)&@?O>>!:e%=LuY["M(kG!4s#RM8:.8)7B+JZah-f^qC5bG.B-2
::SEQ#e(j$I(6/dZbX8a-F/99D7G21+MNlL@CY:.K"KO=+"cHY9<TAB0u+g134i/%E4?=jCqqC4*P*i:
[C!BM#e%d\Vn#O1Bu)C2/\$bMTt;S`GJ:o,%(\^;1q>l[ICbEF%CuAF&]"^X#IaN?rO<uX1;Km"Lq^*n
ZD37=$96p'1HJ]&5e/U1C-)#M=uf,6KXk8L`&qEflF9kWTK6:;#rm>n::dYj"#^<ATfK]gAA%OhGWP#q
8AQ1Y2Sd\RVna@eX2;rmbJ'U])80Rq_nlAd>.f@#j0oU`>.2d<^G&\N[_*qJQop'b=$$:@YIn%%K!pt*
`Ah$a>!4&lN'!.a"h1Ek2EY\9>!;71XLLn`>!5D7(q*U2>!36R?TVFS^UMfW=Jcfq)*DE2D7N.o>!5lm
Y;ocL>!5SBOuQW.Zagf5>rc(Ogc.,Kpol&)>!;I0IAg=4p,#c2jZ$F,?+C&#>!6%P>!4&m=M/N6KsI[?
0Y+Ktik%7X!P$aj.)ChMX0pHf]t+fg>J661_6t#dO10Hqml'Gjd5NC0f=fHjgG=ntAL[tqJ%_qmatGNZ
;RN@.T"2S?&%TWco"ZTV"ZGHu4Ji-+VRul:].#DB`jfD5)8$M>PV#KaEkkg<,.>Ok_QM`CrO]fus0uGj
lb?Ud'K)^I`Ms_:%)*(WU,ja/]!Eikq`.hCa1AUgIBI?AD``Wd4#@A[!;m8>!;t9YeA!QQ[(Wi[A[%<4
niV=_C`t/`R'T/f8\cXc41PC07_24.0Y$AR)a*Ak9.F+.5/$R%EkTr<e%ppZ%6]n7=uBEsXgCtd[(S7P
p,cG@>!3Z_.Qpruj>70(>!6%PpH06Q=1;?r>!4Ju7BK`V>!7a'>!9AWKWA6<J2nW4YWHkU`48/l>!5Wf
fsq;91GSa6laJc.+h^mc)RFcI<3BQ<7)&]0GrVk;9XItdEO\Y'].cH0h7977>!6%P>!8$2@Co]+&Z)os
(F#EOT02j-/3>5d%)1N$&MaNo*3ufWZb#8.:,?`@?+ql$EB%_iSZLVN-GN$]!;lipd_,YY8],5PL,cQR
eMnkg2o"%SfsUq!8\ecI4#eS%7_0q]L:mo*C,(%M#!;n`!;m24C:XY[!;pTC]0)9:)a(X6BXnAX[_Ecs
mPNlW;)2T8#;i\B]tVQ<'e?c$BXMNb8A'3]W3,-[agbh;Lc+6IA3'3<q7Og/LU;E<T!Ve8UV.>OXs*AH
<'=DJ>!4o/XuolNH+?"!:H_lE6p/sZWNH^k>!95MTsu[5'tbtLZ*^7'!5Nt6$G'!Ap9RT(be$D*DRc2q
1+cP3&M`)te1kjKA\T=fSi@t-B/CC8=1r1YHF:W%R^l7hM`'Fs)`b&Z5eN[Jm^j(Dn[1p$hn;7cB/,U^
MEFs%o/mOFa#]VN]"4_")EaoXoJu_&/@^tObr?ZM0Y!jcOL1ai)7W/FO2/*-pp>+RWN6`BS\5B=Lq@7K
4$%@D_*#+b'KhF=eYip;k<(+Q>!5G4qmP6A>!64N275Y1X$#o2a?3ih(9,>8nMJKKN]PUui4DcAM*-!i
ICoTk7'`5n&\Z;r?,'7LTt?Q!+LkgmMnk=b;PKMm?T)(NLc,#igF3Ok?bCJ;>!;+4>!4E!6b-A`YV]QF
K>0@[AA'D,otGskLVXeBbIj7Y<4oEN9>XB=,ecCWTYX[B$bQb\+M7?V&\mhHl+os*"2AHalbO=M6al*l
`47S3oWNhW.(ldi^qC>jXLUU)I^naXe\Dg3G.$DG'>V]&9>TDuB#)*ng;.".h7eER\@\!=?G^Kl^q`OU
'<JCAc(37fF#N,:?bTMk-7m3LhR/oeh7R:-%B\QubI0Vo[5rRk>!;gEo=2%f*&@E!5rWPh&%hA1TK31_
#!<ec>!5D<O$$T/d's?E>!5G>1d&f;b-W*I>!9;KNj0fd`jY$4==uZj9#-lNrNJ;ea>#n'3kH7d1U&Jd
!'PBb>!8]B/3@#u;`K^u>!6%P\MuB%C,u5N>!:7m>!6XWYrl2QI6:[r8[sR39YKc-d_/&\auh@;>!6Q0
XuffM>!6i:>!4r,41Se4>!5G<F$#15l*E(R>!3fe5s);3Ge+6jo;a[[_miT)>!6%P>!;".S%`&h.QKRF
%m4#Y>!3?X&j9D]K-^pf1-Jf(>!6gc::"+e>!6daU7b[Q>!5/44$?b1Cbe7=.Q9s^4$4`8pULns>!7`p
K"X^ciNk5OjLraEj1^#Uah6T<VRMZ#jM3%S#.:/>PV?9(Uc#qK@l+9Mcb$qO>!6%P>!3N]*4oB;M(L);
krN!2>!;+4>!:k-OdHV@$U%ZV>!3HZX>*mA>!:@sqCPl6>!8lI>!3K]6aT!>h[P`(MD].X6+;n4>!2j>
YWQ)P>!9#N*B[LgA@OEX5!3"3$oYXV`[Zs.>!6@P#qK1B2*',H<B(aT/%iq`>!4B!>!6%Pb.Lb<6+:#\
8N;\j&3([k\2Vksf"I8*"tPqBYHdApV7FH!YVt+7a0r$/J2dupH9;*g=Ln2h8$[*4BVn_>Q+ScQ82qEo
<]jPK>!3lfHTG=n%_D0l;ES,G00Q<rQF57&>!:Xq@CIdF;n7^c3NHFDotSs3"uda8d$r4d]t6inT=&Vp
?+KmBMn-5J,IkP%6,CdU6b#(gah+%S-bZUpiO9K5LqYXVMRkj[/\1;^@)6ooPeKo.=1u_krkPtX@D2NP
Oh,#7c+G.0I(YNRG/BZ[%D7)&c+^'hD89_uB>)L']sR:@ke28O_n3@ih8/-^9Xlpm"MDL\rkMCFTtmJ8
NB16+>!64RjZ?X/'!]/3&Ns;\J3;@CVRK_l>!5;77Bp#Z>!:\'>!;gH$S5CC/3H<_>!95M6+LSe>!;ba
:q\`p0s]'7K"UKUOhVUBn@M&s6b-+.HGHJj.OJoE4Z-D+8$PKDRlCR78@qAR>!6%P>!8'3qRTin0!A/5
$+2$3"0I,2>d0*jXM2!H)6t?oB=3)rB>!cE<%f?'B"e#I6aql[3N'9lGeVlbe\*'<p:?j0HbT`tA[,=M
F0o\a;6^ik)R`2A1VdD#Ksn:q=h2qkC:tb&3ijC8#IZ1gDmkP1J@.5@8AN3I;D<$t"gPqHID@&<I_O+8
a#;7#XZ%^fVDH%DT>.$PL,&e=oWs1[Xh$Bh/2X1R9"7;H&N.B_M`WLNKtONM=rfE226oZ^]t<U<0f.%]
-Tsj\>!6%P>!,tO+hSFN>!;C;$U"8FAXg=l>!6FT6F2S([((rO<A8GMSA5@ieZ^%$IP>1Y<4oXjlFAjX''')

bicodon_usage['Rattus norvegicus'] = _(rb'''
d^I1U1c,h*V)s;j9"At&JNLk3!BH#skqWu7#s&SW[]i.\=Z:.Vp,^>V'YNQhF1**t9sPPG)7pKar\m'L
coWgAg,UKBKf_:X^Ul3^Aj+6u@QJ?cX=CqD;`lKeEB,+'0J[3"qDL,hm(I$klT1Co,<E"jA\1,c=hDX4
D`_PoAj+R&*'ImsFtn/%Aj'`h5s,iB@'sT0Aj*7Vr%VeHAj%Y*-9Ys(F0S8!MDJQu;)p)1dCB<=Aj&[5
HamJu7PlR'NjtN3PeB`"#-fm9C81=2@_TX]]f8j#CH#ig?*P/+_)!Q$<4h!EAj'`hAj+0sT=JPs*\]?1
cT>`%Aj+3s1Hf>5kUt@H!^1-YAj&FAZ7]`PAj,$4eM:`"Aj$J_Aj'6ZQ*WG5"tYorf/Qj>Ek($bAj,.U
><?F[Aj*^eeN.;*WO5MaGWHL$LH0H8&%>e'Aj(>o]fB[fG;X.s$9VTVGIUd<Aj&@AAj'`hX1Dn+9!t'L
MDqXnAMM[h'fG5,p:\Tqe#tI6#J&Eq!P?)n2_f#$ag5P:.5n[l.6>O.0"pd9[(3EP,e+l-?+b<gf._BW
Aj'`h(-Tc$coYi&@Cr<t?9Mm`$9Sq]DClnkAj*[a9rWk+kI2$YZm6D8R_Y:I'Xuc(B<ihjbIXT,M78a,
lnAT#75aoudknlmXM*IAg,mP1SN1nu%(mUk].c1Rn?PbNj#c'W`B;+$pU2n@+1PCY+tZd+3P5a,coOV*
RQP1FAj,<>f/mS-G.FG2a#kb4;*'%]3O8$/N]\gH"Z.5Y=Y%Io.l;N.A%`")Y;n;B76*.PDS'R(Uq!-V
<]XhUAj)/77Qb9G8Zr[ci&kU7Aj)PBKXbVWAj%M%_6RZ9Aj,iJAj+L$Osc>Rq(WpLkrKlnijpj%Aj%3B
0"g\Z!j<?M'YK1.g:h^BE4PhN]!kVOX1q07*B#sloquCbBfGuNWAnTQo=9$(Aj'`hAj%1t?Fj`3N]$;c
*khonVRuE55eRlFFMJm1a1:ZOCUVF#;SaHi1VB0kXMCL5.(3$d4LEk>W4^!Sf>(M$%_P*C\\PA[kV-AY
]X^V<TH`:&,J<'B=2#9XVmq2^7(?1.0u-2h(b./PGJ&^@KXo1:_7Kf\XME8qMmP1J`hj<V6bjDIG.rI;
d^P1E41O(U-*TD;#/Fo]E3`oaEk'<)'u#a>(:J%ic*d%&^H.-0%R!<B"1V,hj=SZ_=>j<ne@Q="P<(S0
_DkUYF#o(9W&OoAmCPPCAj&=>jZ:799=1uaAj)n@dBQ/#d^$g#4Z';u-,8@q9J*!@H8PQ!S%>=NT!1.*
:c\D84#u%Xi]I<*h6jFKAj&1<f/g0!@5u[sbWC\Eo/'$%&Nl:?P<979HF^IH._$t;$*KN*?+I'k$p%E7
?p/*bAj-&SCcl;mf=7,/Aj,9=j>mH(3]!3dAj%V*fJkcO"ZTL?rA=sB%__BlAj,E9JMqX.UUkq4OgbWW
N&tW7Aj)tOF?F.u]rk$i6To$E:H_0-)n9KCjZF5;4XF]'Aj*jh76F=.cEJ?QF#UWkBKU\o@(JH\Aj*UU
@Ce0Bh_f#UVRhR>/\Ori#J-]g;QrX%h7t,D1pR+r6*qFk/$-ZLkcIcC7D2AOANXQfgH8=q;S7WETW$F$
]K9^gAj)SEAj&gN#G7GIUHE-O#X+2/8hoEiAj'cg<[;9?Aj*:Y.m;`O`iNc85.C&5KJd/J.(I,OAj+;6
@l\9dI6;+%KfI"4hmn1r+#U2^.C*/.9t,C-W]LA9=>=PN$T"b9W]=lU*kZVUR66Ed90#d)k.AVmb-VmD
)D>h[fs3Q>^p)=k&&:K<r2Be0hmc7j2SDts@C9CKHF`B$ehpkb`AHX7-b\Ct]=/N_^Tk5Y#egYT*\j1p
niLGHq)epE!]^lV1qLjl9ftX'Ouu;rL:J'VY<%HA%_R$EZ+5e!]X[=:0#>H2(qQ*Fp9kF>!k`k(8%;d"
[]I0M3\!;!6an,J&]#^&[5!iTjKb/a/AAm3347hY#e_@kj0fT0!2t%ME57.2S@gbpI(UrE"MgG?X1NDd
9fY0krA@h:0f"#0J%jtuBJM?Jj1%^kp:LpI#-3Wl&":;E/%jTFj1)J,K#!&J>VX:0<4(&]OM@Huk.\&R
aZ=#sAj*ggHokq'NjM#3a#mrs<BSGcO1/^aAj$D\&[H"3Aj+s1niUMIGcsFs<'8&\Aj&pL0"Io?Aj&P^
19tjY-opKD)RP&UJ@o_JCp=1(XYAeFBY?M[Y;lj!i%en-RP_Z<QoOIqWk(#KAj'`hAj,-9qmpB&VCD^0
4?7":Aj&=?g,rt1>9/;X>!5)5Aj&1:LbNF(Aj%>#bc,2;Aj(`,q)h#-,->H?Ha+#;of.6*`jt@eAj%lS
N]Lc8Aj)_J'K]nimk;=9@6A-b;`iJg[Bi@]Aj+9lQ8iJ>))N?r?9@@5K!o8SAj'`hAj%G''>,kZ!4$3"
1H'fjY:LHm/@6)!S\XU#j-C^pXLM`Ms1IO(p9.E"n?q:9/ifXcKKK#jDS9[F^,5tpbqU*EB"UO<0fGl6
Aj'`h)a34D&j/HCgq%)\Aj'?]bWBZ&>Uii:Aj,fH[lDqrLU.[SP;GN_W5"ETV)!FlD(oo]d'tP^5dS*Z
;7cV&jg=OqKJ=LJSA(Yup+h]4$lK_dIC_VMfrsnQ5.ui]qR=h[F1$Y17DP+p^qQ,K#JCY`:r&I3cafpd
^GLj-0JlQbU+;$V\@tcl+Ze^EAM\NY8%EcL,<%Ee/%ICF[(N'A)84,)rkSTJkd?\fQahCMZ,+\r%)KB_
Ji[L,Aj,oMAj$A^82k?I9g*)OAj(r3$F+2+Aj'K]6Ek&bAj'`e=?RKaJi%(&lSYe)YWCd=J%8B8Aj*H'
Vm"B&L,lB126u!r!P,P:nXeVsOu*c\35%'kRlb2mpSqggOg's/L,1PDhRM;qAj'`hAj)5<6+^_l-SY$N
WB"QRAj&UG0g0,3q(OB_W]XlVAj'TbK.LUtAj%:uD6db:Aj+d-%R!<F/>ZrAT<'e-`]:!(^pkaOAj,jg
YrQDZAj$J`1HK,2rjE(p5!!:=5<,i+41M@MAj(i#^E-uM?o9Gs3&nN1*kMS:Aj,ZHAj'`h!ki2/2n-sm
N&D8!?n/1RVCkHAot;n7LU9mfqm[HRC:qNl)mhr=R'_]0SiL7:;*4\9R(6Nc.'Xi$N%1j<mC\mldkuuh
+$F4!Aj&aKofHbKgpkcpk<*?>$9[o?`j9_HAj&L>.CJq0`O5t.&Zk@M=MOhj"h(P=3k/_*be"`P=LO,I
$`opZiAdPk8N:?@gUpfJ&NZa>%67lFO1Ac.nh\q*r3;#>j?1aKr&jI13OYSCo!K.>RPH;&3kBAf5<O:q
6TesDAj%5!#!?K\R(;?@m6#n]@QTi5EO_D^7QO9Tp:D+t3jC:podfAcg:`.sFu@AY8iQZ%[(C979XPp$
,s#X$Aj&^H3':e9j!qf()E_UpAj'BZ0t:gYAj'BYd'%%EANc)8^,nih,degV!Ap#tr&Pn/6bHnf69XnF
LqI#sD(ps[CqT#:R_74`gUI9g'<R;-p:tmcR&l1Z0XG@S!LE.7/Mu$<Tt7urAj'`hAj%Y,6b6km]/Q*<
EkWg4)nSYS/%o-!Ohc1Sb.?EAhRBQ"hn_=e_RlYYUqd\L+1(gU-b!fnqRF>KB#*'/`O^9/I_brn=#7k1
'>(TVW3JIodCeYI._\Eaf=7KYKt)09.`%Odfseu96c%]hn\:U*@_DcQ9>G5Rk.0BY::&EZrkR@#"MSW_
nZZVrP-)6u/24@cAA//>*ONGf/[ZV1UV,<d%4.(C=T_>\Aj$D^Aj,'66F9HMa#)GOXZ?s%p9tDhAj)22
HTFtd6p5iY4?Em5R(07\Aj%n4'0Y)1Ejf75Aj$,L#-q5iA$maEF#GC+UV6I_"#O@BKfBi,LUT$"*B&m8
D7TYJ`O<:]MB^oQ'u+t!VDHOXO"P'%e%(MtHSU:,=M(RlBefZ8\#1o7-,(KW;nW4E&%Wgrk.R_'\t]8<
`\tt"N]L9%Ji"!!.D.StfK#We'fbA,h6cT.;EVTFfXNXf,/,M9iOL)=g:t))/23^&Yd+PEd_Aei0YX9g
Y.5l:1,M&$^Gr&Nn?X;[4"t#)M)jQR_7O;BV`GJGUUel:d6!=IlSWB7<4Gseosg8HJMh,MWk6D4@m/>M
OMFT'EOp;,GeMn=Xh1sQOM02MJ[cH/!l58T3\kcl"2&5/"Lo++S2JeY%Ca)45WWL?Aj(K'n\&Nt&@a2L
FsL3NME+cn[5k!B'"OPi_)F/483>N]Kt,Mk/NRl.A[gb`*BauoZ9(B9/>Nb<bdZjrGWD,#XLYr##sA^+
_)M]_4$>#P=uh[,LU[jT@5^20r3G-3p9nlu$Tt`%:;'agn%8V,Gc2!/kIq;%!&V>9A24t%Kt_O_1:rFK
EPLhP4MG"5;nLGeOMQsi\\5kiM7jG5*5L[GO1_R,q7c,De#mr&Tre^,be>PR/\TlLNk0JL:;8ZsR4u@f
b.!0T.krT^Wj3-o+2*<,E@qPXH8;q2C:Tlk?p&V?5J?*__7p;dbIG$Ugq\%W]Y0rJ%_-hqbeHfS?bF%\
e\#\-f!pXFq7,h&7_f>BfXMR*X19FeGe_52jL;e7H+l_VV6r:pTXqtMikV(oH+s-fI_&7hjM<.XPJ!6t
\@EBc27`.c]Y)V&be_!*g:D=9_Rs0gK#!ehZ+D3q]"=*:*kL=CUqT^>s1pV,Gd2V.n$u*(b/+h,28Mkt
D7&gqY;e$m/3;?ES['"k!B&4d?T@"(r4$?%eNDkOH+`i/Rl!2]9/D5L!5'I3U7uq<p,)$DT"`OY82hj-
/\sWbY.shI/\jN_8&@^0KYFb)&\S[i!lC8;LV&qh"g)B"'sn!&Fu6*X)S?qJAj'Qc76DbV359&gU:U1\
n2=lAAj+a-\N=Cd:Taj_KKEd/Aj$\d0t=YOAj%t.n[N0oAj+<sjuI$:KX.75^9ZNTk<"d1HFlL$Aj&#[
(H?"iAj%M(iAbF4J[YtKUcE$MZ8iFRhR=jiAj'D*GVl3Yb;DOG.QH`V7(J+84$@1=Aj,KCkJ#k6_mjYF
[_'kpO1T\G.(IU2CVU@gOh5)6/%p);n\$K`A@Il7ah&fOq_<=MLGNBm>eL\/`A$#V.PR!rOM5/7r2YC]
7(R9FI_,6]Xh*f+2Sm_IKqK*a-+&Z@WP)QJ#d5Ga]X@gFUqD.,,ICl/0u3!1"=r00`ije:FMABgb.P[#
6S+Nb&NE<DV`M1EZb"IAr];Ac<][ZJB/(;c'0BAXPdJ@h;)[&dS2_rTrOa119!tJ&[Ac'r'"t9S7Pl0r
dQ7=h4$*s9H9!cDQ+R)Y4$>;].Qh0#BrtZ!<')Zh:cA;5.(Du5&@(,k.)/8.]fF"jni@RM3PG2JUq@L*
Pr`M?Aj%S(pH3%N4u3O.Aj'`h`B5V3:UF^sAj),7-89$pAj(`,JimX..BlT2YVf08005)s2S,YCAj+D.
fssm,.55AC>.TrtCq[-aI(+__Qa9T$._j6;&MjC!`N*T6,;g?$82Rn<K"3KoAj'`hAj%b0/%T=UIPT#,
?9)U\Aj$PaD`hVpRk:?q'Kp%kAj$bfq6FTqAj%4sW39erAj%7uE'._qpS?G((bYkMc9&A;d^dUXAj&>d
?o_g^Aj)D@0f`i/KXO3/f/RA*"ZeCtQa_]-Aj%ZGIl:n%Il<9J,<'I#L:STjAj*plAj'`hE4ojHs1$Q@
[5I,$L*q3uR4cT7"2E?c&[Y!;>.Tj.0tKY"7P%asIC5b+Y;Am+LH(/NgUqtrYdOhJTscPcT"T9Th(bM0
j#gp:Aj'ijCH5uiFLpWtWB=cU3BSWLT<k7PAj'HY[^egbHFo(n;RMjio"TN/]sIgLn[,7#&\Ju=hR;f.
4LW<QpDjJj?*RG=XhIoH!]F8m]e?:n8%g^kI^C]=(V=<>br0>m90/>!,e<k6`O^l83j-fBL;&#HD`$sq
9KS=uAj%k2i]2TQ1V$gR]0!\fG!#+K0"Y/mIQ/^alFKs%Y.5CSA%!MZn\4!2H*E+7/$[U5b.amdS%NXC
)E;=lAj,NA<]jtWM65;gqE&:PAj&UDf!o<TAj'6V5Ib;gAj$>ZAj%4uQo/)2Gr8_bb<50u<4kXVAj$X3
T=g^@/i3X?bI`ZeHFs?kNk+d5GH@dUVSHQN>V6c+?aXK/X='K!5W0'6J%(S$Aj'`hAj%M(I(NuR^GW2U
aM=+V$GHb\FMF-UI_jXNWP(O1T"@M.cb^[;k.P]Kf>4;n4M0mm:q>1,NOrW/4MZZ](qZueR_d4\(:2`1
`k9g0f<ZU2FM(5H=1JsTWOg_7%ChM4%`+XKJ[eRmQGJ$_QGJ3e'u9UV<l$)qbe5aEla]<pEPh(U7_f_P
HF_k>7CO\Sk-F]`@_]I\la@eF&\Bd1)89^mC:.ogqmfunPW9I;F?H`g_6t:G^TDFV+>rJrp:RZ:RQ2Fu
i&PC45X!.L5rrU@NO[G"g,rt1mQA9FXgb>hAj'0H8%L$$,.u\]408!2>.t\06a2'5==W;TTtJT)[B\GY
`As,E=#u:&N&f`SWk-qC76PEE1HR$=OLD_UfK"C8e#P;c#s//EG<7]FppoKJ[Bqll-ne6(LV,gUi&%4;
C-6)kAj$kk\iXLe-FkZi5WpDVg,UZD0sS5K.Qe5$g8Wi5::gA-p:*T"N5-"4[5^L^eZo(]J\4+Lo=E4&
coG]$&NpghD*)>mfX,*KPWWP@a#nf2V7C2$Aj%D"19Y:QAj-)QCHQ,jJ#R$C=ZL(Wml^5"#eJeOAj*m_
p:T1fTdp2U"2&A*2S!8)_mY[gPcPk7<5.69!]elDR'1*bPVNS,4>T_p8@o?mAj'`hAj&XHM7R:^<&%00
br^56Aj+R%N&e4*Q+G0t,<K<kqDkC]g:K@%9fa?"S[`&bTfX'rAimIaZa>TP)n$\C\2?shBtVeC#<SZi
r&++/5s/^<$ol$b?+?@bn1btHKXqsLlaW6?Il]9fVS"=a&@aa4\%$"V4M^!^Rl'E@#IefdotG7PLV$]t
4L?uQm_+"Y?+,9bi5"-W0XhA#GJ#680YbT:osl*SY.FKc9JTnVQSg<Ti4NngPdfDQk-Imp:qk8a=t^N!
2DYk**B%Cd^GSPE9"[bXQ9&V@BK;)5,d\CLAj+'k3k?iI9=m0kUUgl@8\lRR&[RM/*4bLJq7X)<]t"W\
Haq5++L]%dbd@efL;73+YH`ts$+\s+A%lZjMRNu+1qUi.9IOtfd'6?NHGGuDT=fli.Ca3.^qb92Z+A#j
9XWK[A[_6=X1A#63Pf[E/[oT-)SB^r\A"iS`k'm;ZFVEo=hJFTiOM4`4i'k#jffN4R^gJJ7DMd3I(ool
F"E/1M)\m'UH3!MK=?Ut-T]4/-TPs&qRC-#$U#%]Z+*[oBKBifOZ:0;L:XWNFYu*8a#NdrWP!d9!]kV8
8&8*<+2C=[`P?9&(W*l#"28cfNP%`qLVY^ZMnCj]f!mb(5e(Ykat55.M7`mNg,j79FZKUdjLf(f&\*o_
%68#`Aj,KBGs#@q\?m,9>!-[bAj'9R\%!G=Aj$>V_6ml<Aj)283'1_8?aftsVC2p:VE=FSr4,QZAj*K-
V`A?PAj%4uF?!kq(V1SK2`YJ5&NLRa,IFC/Aj&+*3&5)/^,=h1ni15El+%BhAj'`hAj*[en@Ws-&@CO]
U:B3jZFc+':plLoB#*Q7>.:lM>It-QXM*Z(B!l!T%_-L=fJYfN"?:'P0tg.?0/Q2-8Z_0d`kCoO%5.jo
jL#f3/%Hb/%_4="MSXP>X>Mai$CpsY4hQKX-RHL:B!^8LV7STD'!$L>Ktp;@8[E':VQ4,PMnECO9tA4q
a#>A-K/<kEoWAocHGMDBqQIlF#.S'NFu+5"LTjMk3Ok?M/@<__=#:l1DS7j:rP<QlrPA3C/[m(;0!KW.
br&M.?SX2jmBu>h6bP^s<k,fP9td[Bl`n[8r&LK,DS&Y*283ZcgU^S$oY;-Rla:-5.C^o[aL1iJaL1I\
0g'&2Aj&@>2EbY8c8;7UAj'`hs#fg3"1Vr+Aj,TBD'W^VAj&aIAj$2X:SjIA^Gu]b0K[f:R(=4pAj)0[
B=Y#eJMGW]OgZ2dg:S<50!s7f<iZ)-K"aCU&i`b%g+[,%fXE1hIl!HOb.=B)Aj'`hAj*.Vrjuc*7ATf@
=#Wl7HT=6rL+P3d;n;t8e$\8GQF@F7:)QeEF>Y."/@9CR9e5tI<Ao'0UUss=ZG;mE6bu./rji?G=uFC/
<OD?O<kIrW[(&?5Bu(Uq9tc7p'u#C9"h+uQl`j:$ijs?B>eP?iDn?[r7`1%sKsY7#`3f*@#JB95/[r4"
'K(7m[PR%eS1FFle%U5Yn/epGB=Ha.=1k]7Wj$fTW44'/mko>32ECCclF]kPn[1is-F:Cu(;:s&B;BFV
)Eh[qAj%M(LHK03cFGhqAj&UH'Kj&hVm;(;Aj%_'kI'\8F1\D+R^Jn9,f$];K=E8<&@H,YmCO#kbd\!<
8LhHYb;1h*1G>N2o"NPV*''J"?8U]Q35,7&Up[26Nk*jpgbkV,QT8tC2S@KuDn:t@i3bMWM7nSRYqiYt
]0%2t/3SGC-p-]V8\/Ip;`sS1=umuc0=h%gf/QO51qK9b@^a:aZ+'M7$c'Zb`jHetK!'X6_S'ut_n4$k
GWIrL!'OCCjZ@KF7'RFd)a03BAj)nGP.'+-Aj%q0YdJ7.hE7Pl+$D><kH$!l-T#Kom5cc,I(OMXcTEnh
e%EE*8[0;KT"IP%H,%8/#J.ISm^C9N2S]C,"/uC;Tep@E9f4=\J2+Jm;nQ$dAj,'7Aj%_.Dn0ICc8Dje
]=tYeh7QLt]Y4umUVSe&_n9a"o",[R0#AIArk0DiiPG&sPIt2:'"\aco=itj4M`be"2J!Tftfkd-FaK#
BY(7Sq61+9kdr+II(g-&5.YI8Kt+>"4i(R@e$\#HK>EDXi4p8G8\fqk+N!W^m(BF5iOX$C6Gel!d_MHg
+0C4%*Z\IkV)240r4ZYhr%6O4XgB[mQb6\6Cp#:uBsf]U>!"Z$Aj&gKJ%#SE0f*FM5rTFfA\3c#hE%^E
'0KnhAj)kLSNLLI9=YHoAj$8ZKKQb(?a\THAj$kaJ$Jr1J[ejb!&6u"E5*)D/$(k>.5co/m^b53=g"hX
Aj(W+dQD,)Aj&^J/heS5Aj'`h=#[WNF>t:'Aj'`h.QM*(Aj$YeAj'`h=#<i<N4B&*CVFo+A3'ZO3'I:'
Aj+C$+?X7!Aj(Z,XtQ&&Aj)26:)V-\T/8Pi69SpDFtu!=!PIDRE]BdFZb3_(Aj'`hAj,B>]eO+^Aj%\.
/3IN-Aj&pPpH3%NdO$_2Aj'`h0g-jFIBmHJAj$beO!nU'Aj'3VAj&4=VD&TFN]:`8?T_OI7_*IuAj*7N
Pe@a@27!n.0"nX!e%Skq$GA$uj0i.)IDMDc6F(IC2_eo-A1/ifP;FdPlFZ^KAj'`hAj%;"2S3QaTJ(@J
m5eiBAj-/VAj&CB)_F?<jud6=Aj'okGVWkoAj'!R%P_QYAj$kkAj%q54fpk1l`abQGr15bYIDA+Aj$;O
90?fLAj'B]D*)>m6+Igp6p,'E`]&B-XJh=CAj'0P_DPpg[QB%%/NBakd^rmIAj']gAj'`h;nQ^*bI74/
8N<2#@Q5DiQSl!-]"D0&0f"b04f`2&41_pU_DR+OLpm=CSiD]c@lq1_Pe$6F!3\_j%5:GdO1]q?X>jk#
>s)^^Aj%;!_`DBmn$tnM@m"?d+$BolNO?V_Aj'ES'=]DK.(W!L9qfZd<l!cQ)_3,BnZDPoc+EF$9X3t>
o!tU,c+0">jLF-\rP8*;8%E`TkdtWBID(ZSrO-XVDnZ4`d^iGiD7TPV0#8R=]Y8d/ot?O()o9J.DnQq%
P.I3spUk%JRCnWp3l:L$)n[3+rOsJjP/+NANP.*_6F@'2i4P8`@D'@f@DY%9WjmbrYIkR]5/HHr&&DVa
LH9$1Aj(K%ME>E57'ghn'0TqjUHGV=o!W-nAj)tN!jZE$Aj+-p>!:h,9Wr%k:-8nHAj&+5:q<qmAj+SB
/\E.4RBOE7rk+&j$GRXnhRUD-bI1$U1r-0'75H7(Il:n%HF!$#82qMNHb2U+Aj'`hAj*agJ@fDV'X>81
pU'HB\u_2O#I&N[_7mIe%(&[:Bt'D<HG%)(,;>(dPJ+!'9=Hpkj.AcIm_5&>J%jmT6bN90[_HFf6F*u3
4giM:"0hk\Og\Dt+M]V3)7E&DI(;)Gf=h'nSZY/hDm[Kg@CXLfV6ih$@DGdF!B.$fBX%oKVSJ/$Dn``g
9K&4piAQ<HJhWTHLVJ]rpb<YqppG4R9Y*Qp0K$9j6FaBVL,:kG9KTsJZ+O4%Of\Vqkd50<,eT&CAi/,J
2a(b9Aj&ID+Zs@"rjr\(Aj&pP76GQMgT&4PAj+'i+YGr6P.!_9p+eTaR)%lEpTV$4^+IJVMS)&*/%R[E''')

bicodon_usage['Danio rerio'] = _(rb'''
+td"\JiLq4Im%7'&@dTZ><=#i^+prmoqj&sn2^b-e2`"AIm)(;Im(A(B=:8lafS]&GdTZB?a4K/.6Z94
&NbJ*Im&EHF$2BD7'qG,Im#hSYVB*;cDZ=TIm*$UfK=XHkV+JKq)[UtoXs9HIm(_3Im$mrn[j*,`O\5m
3B_jTIm(q6Im)gRij>.9Im&9EYW93RS[X)3Im*<]7PoTXIm(h4s#f$tr$?hU?)s_[j0\]hJ%Ra"Im$H"
._0RUfJEuDGr$O&;SB=n.khSqX13#U:qeb7cSU`oR5]UYCplMeUG<E@"M@MjIm&9EIm(k7NkKp*6*kYp
1-L+MIm**X&3G,!ZnGEAIm&9EofPQ(+guk`Im';_CGVqMFZjn*W]5/Zm'aYh9sh,Z[B`'&PIl,qIm%3m
?o9`$N')2BF#Q0A&%Oea68lA6RC4(o0t\>[Rlo+V90#'r:pJ\6M`.Il^q?[.IQST3h)p0M_n;d-Gd`)b
eiKEWIPn/\&@7,(Gec)GX1?6_6b[-F'YI\Y-*C+O-SfR#ANL5Y838ae>.g(\Hb)JR4M<,SFh2%iYWA2]
(Hm72Im)RLCd"LT1V%uuIm"]3@kf&aIO)E^Im(Y/CFc)5-bWEZ(::'P0#9ob.(FE3;S4!\;7rh]QaoYk
X>o<&j>[B(MEJa1f=V_TV)gl@FY-OqTt7Y>IlG6S4un*UIm(M'Im)%:iN0"@,W!+nmj$/Q5IP\nIm#tP
69BZ[Im$OiIm#eS7]`ON908:oT<=b?9.eUP,sB@/R6-Kmn1^+gBKEOY^qB\-Im!io\i`&6E3qVcr3>`Q
Im&9E#WurcIm$^nYde[7Im&9EYrTBU]XE;QIm)4=NNl\0E&iTZmlC.nijNJ]k-Uj?,e+kt[_/4i[Q8c?
N4XbOPd[F!&%9EUJA:3Irj:If5.qH=J%\i8MQEVaG:.l'FLu?H69'HT?G$e/4$8!UIm(G*41p&+'=R*b
!57a48A1\1,J835ahOgfcFRl+=h9C%_8('*kIHSeFhHA:2)D;GpD('D*k-'p8A<ffrjj&]n%HWER5lt5
Z+e>fIB]c^NO=YI'tQ+J:V1;PD7u.GhnP_l0K0?LfWY(BbdiA4[(2%';ns!RROncWBeZBj9"p@jm_"N6
ei@lXS?]N"CcB/?9#,VV#d&3],eVa?TtAda1a[:NAN)8$,!C'*>s3rs7C^N'PUkl:ICUu8d]t&SD`uc4
<]a;B\2k<dl9*QVQFP@*Im%^'ag6UTX#4cSIm%a3Ik6745eMk%2E7tJZbHW"ZDh!7H)F!9s"*LrQ8079
@6B$&ffLQCIm$IfpTdj_3'FT.nhkhTR5J&-Lcce?HT6L<Im(G*Im)[OrhUl'QSE,0ZRm*&GI7Q6>!4r(
I62pAIm(q:5<U8Tk:_<JIm#;?o;?UbV5;L"Im"<(^H*`'GG"Ca@l_[eTY7]lIm*6Wb;<B]qRO*n7'i7>
Im&9EGs%!GIm"3&jL/#MIm&9ECcV,Kag_^AIm)^L%Q&PrBfi7TZ8PQ8cF>>_MQQA*fX@N^J\L?Q'053b
oX<a9qDDh4-FH(>4hdjHW[LOtEOI4'!Pb23)Qt3n/i8&@RPX"a6o8d?::u]KIm$XlIm&9E`k?jbb.)CP
Yrp8nIm%R.g,ui+OuJdkIm*fm<'9>'K.,G9Im'qr8[ZJn?94u>#s)6HQn[5UU:>'NW4<PPMS,1\Home%
rNSjE-8_8G;DX1ahRVf,hRJ!E,eYD4P.e%M@QCtPf!d!,)S(eT(,O1E1qp=O2EH&l$F<2Vn[]dHo<m11
a#[Zg$7kX(pU#1XC;@0e#J/p-DS?gu;S:Deo.%)Q3[s&NgcH*1SN1/Zo"3"(L9E/:f".E[GJ'WY/3Eg<
.6N/D837YOC,`dacb-#52*C(];QQHFL:AidG!+S>=g:RZo"9'&FgQJ-^qc#=`NQ_^GIWL90=dH4go*@t
(S`(T\MO>s[Bqm(Fhf$/"Lrup1;"R>m(O+F"h%@CVRmeW8#CgK2)(N04MH-F&\JC^<5#cTAAGXfkI#?E
PICEJ,W:f@,W2*sXM(+*3$[LpUqI8L;n[RhH8Lhr%'r[=G.]lHd'hN;l+ku^-8U:cMQA\GPJ6h#>J4W#
Im&9E5!:tfIm##>*O\R&Im&9Eb;gA#=1<ZBIm$7]6*l&(Im!rnh)n.edk?hGMD5o/5HQ"_MRrsNIm$9.
,.U*'\iG[(3];OO)SFogi&(6j5Hma6ID#A6pG]=d`\)a(N4V_B"?(WgFhHcqIm&9EIm&lU8%a=7B=&^@
4?.gRIm*HcbWLA<k;@$;W'"cWIm'/\gp;JnIm(_2Vm1_7Im&KID*;l$,r'm4OgcYg)mVZ4KtIJgIm'('
Hn9b1Im&6Caui9Z1,sbH-9ZiAl8Va*S@^X5Im%?r!'>Zn#W;68ffMbf2R\)uIm&9DIm&9E2nb;8:TT%/
E'%m?\2-%Hp+@o,f>"u*MmuBkj1HDFo"9L`R'O$)&>mr<=Zc[B>W_L;@D74S<O06=o!nA!]"E<oeN,On
(d(b\Im&9EQoqW7Pdu9,Im"B+C,R>"F"GWpIm'el!&m2&EOVSuTJ$VW9#-9<""^=V;(,qVlaM[,I]K+o
+g1)iCTU&^T0#t2R(=k/5;X<5NO=A93P(HYi?n$'^:C."OKh8,5W16uT=hTh,esAmgV-M!,J`?PF1K6&
&$Wi-atjPeH8`f#J%U7i5!.4Q';ft2`OmM,b;1]ZJ>bf?WkAqM>qdS89#,;R7^1d]DR@^$ikT`Mft\ZA
A3GE*Im"c4\NC-Z&%-mMIm&9E=ZN]J]X3/OIm&uUVlG50"?j4Un2_(?*]>E/e[S++^9Bl3=M4)\Im%9n
Mn&sK(-$]D=/^L),J$r9Fth<'i3o&]O2&[dM(oCL!k!M@B=l5Gg+jg2jgJPVIm&9EIm#SM)8(G^h5'R&
PWXFYIm'5^B0C`-'0@R)Im&9E\i^]i`NjtVIm#>D%CCUJIm&iSQ98V=,WU?;-FU<?cS69@1V8)qIm#9Y
0fFMEIm&oVfK"FE/hSe?+$>$9au67^"h\M,Im#>?YVCVj0=?KrR5st$$+<SkIm'knIm&9EMnB]dijXD#
qD^@:3\93pOh(2!9Y_md0>%7s:VKQ9)SE,\]=D:V5;>qsIm#GJIm&<BPbHnq'"HPrW4<eVgpgEA!Bl)f
a#d`nIm&9EffWP&n?II+Im&cQ.lL]oO0i:PIm(.u_BeJ0B=kW54Z*GP;SCAQK<Y0]T!jrnYI)P8e#C2D
$p#h#N&`s\X?>f-Oh8"\ml<'UCobIH=LZU6I6/ja,VkoQ-Tj4IlT.Hk/\-$c&i+)X's)^48A+c+YW8)V
^,dr2Im)^P-TmJNo=&TuGs!Q80!+@r.Bq\fKfn-JE]6cWF=iD5coVn$C:`%Z76GrU?p#>g,.c>f!4O"3
Im&9ECH/LZIm%X3Ejnq/Im&9EJN!ou!O.&:Im!lp&\0>:$RZB=(puoJA%kYdFL\E>kda'f;SP3"qC>LU
%)#HGpU7'3A@tsR&&=7:[CNNO-G>q^KYT"Db.32=c7j`2>.hg6nMh.BA%A0lIm&9EIm#2B&\``X7(QS_
pq(=O5eGCST"5-9KY:a&]sqad\[aH-r4bq<U9UT/Dn`!G`\8+:.(\`T,.r<67_Lsqp:+SFj1f`Fo/OS!
V7q_g0<g&:'"gB;(VOt$(qMoCke.87'u23.att]^VmeKF?FlUcfsTNR3PJuI/?^P3'Jpu+mD"$.H+rZ)
s#EiOgUN\0,WT,;350;bl`e[Gn[qi26Fjb<feJel$oh<OIm&9EIm)45:UEeYa>N]OKr5\G%'u<YIm!uq
(-F-1rB#Kl5WiF8[^LZKIm!ll!Ni.Xk;"VLIm#,?Q8oI=kIQU62`u:AN4aa&-oto^mPKeXFKk!l2lQ1+
`4-:/$b#i<br(_;'=u\s/@HD)6b+PU;nGIQ8iKk_(V2^d"uD=J\M>fr8@\aIJ%M\k\@OH/"MVa]'0+(F
.CllAh)&KDJ2P)!FLN5I+#*;s4M%E%?+d5GCc]JD`k'n\^qE.;2Rn"Acb?iqhm"-23OnC`r4U.X?Ft!\
LH%4Q0KELB9KgW_n?^h0>!.9tJNB8^6b.\0>!9e`OM%hW;lIF48@\#pd_4PFS\-d7?+Gm(!l/+ijYg&K
WPQurWk9gsG.ku/>e^QVXh=eL;8,N8c+ml"M6UU)'"39QTt0VN$9??nAZdmQ0fa_HIm$RjB"rgYE4)E#
I'Rk*DREue[kn;gR',\TE\FMf-n7p$N4S40,rb+r#J:Ksa>kNR%6/_p%Pu6cgprl\TWt-!o=Y75=$"%,
6+e<rpp??q*4/;=HFjBgc+M?6T"ckj%)8",0fFKiCq]eU3P^9Xc+E;Q`P4pTjK:n`=M%)6p:UpGp:DKV
RC7:J;7Uq^+0rhq8AE6W=hE7q!PjK'aLqe`b-9g3BY2nP^,G\`$TXV2]"%5hc+LTt?G5:/KtM1OIm&Om
UUm>4VmS+c5cicqNP-)`dAB.:F1`^,/\.j^%R'YDC;6f+<l!at,Gl![@_UBs%_i%W*k[QDXh4lrf!2oc
;S*IHl*u\^U9t3<Dnt/@d^VKR9Y:kK%DS%=c+)!2E5!a/dC2r_r3RHV7)4A^DnO3)TY419@)?KkK=uuT
QG+r`28!b<T=aI&VnhK._n&s`S\NF`L;@<64M6!UTXMAC0"o!3*kX)=X2-:!n>rA!g:SB=q8/3,f"i6<
dkcJ:!A6i%@6E"$34HL]W]U>G/i_!81q.rt)EMUm=METKQE6Q.C+Ah`>.\]--au\uTX^l/*5V'S=L3Ik
8]'l.Ekk&W)nj%s2o4pmijauT'ta[^]>EI=\@su>Ts7Z^5eHPFX#A9bF1NGTIm'Gd_`0e>/&?]uhS-'M
+?<akIm$^l)E`L4cSp&0Im)sWHTc1+*4S^*Im&oR2S"<#Im"9'O?A"UWAlau*AeKoO#oNcJ\>JEIm&Or
_5r,LIm'MgO?.kS3A/fD>!.9t2`)O:T=c$uIm!c_PraCXe20KSjZ7lS#..#d*Bi^MIm&9E'YdX1V7=i6
1UoHTqRe*fq6/bfBY_El8\%=&UqHc@n%J_30"Mb+2S7m,(c8lb[Q5<b+M@8-GIUDX/\BTETYHDtnZ<bD
$,"?hjLVn0g9[ul(;Q=h^G[LBqmSPd(V^Hn3Oc*%l7t1U8@nIQ%5C*s%_l"%nM'(36F8VVI(s/J?bNtM
c871:AiCbk5!=3R4Kj#l5rmsbQ`RAKXg2.i;)r/<A@.%P+#Q,@7m"IE%_4\_Z+>h)KY/;<\%]bl].-4\
7Pn70_)Psfq)\aArO&1YIm"H+i%q#dm($0#:HEg!aZ3*We%"C!LGA+te@ki=*BV=ol8t(ehS3X1]"[^=
Im&9E:d&STIm#bRE\U'HIm&9EQT.`&WjdI@Im*!VY;:YkIm(J+f/sL*>W5VF8uKN_P-mBY$GFV?Im&+[
K"H0,V).YKcF,8XM7m2s1U,(Wq73T;lb@DDQ7]YZDm4^Sf!oBToeMsr!4K9sIm%p;Im&9EbIrBg257<;
,s?`@Im)(<`]S`6%m2m9Im&9Eh)jj_!P!VBIm)7A8Z[D)Im%("X?<aMD`N;1fIHSOU9+Qp7D10-Im"RN
82u)^Im#5Do/]Z175TKWl9(_%)Dn6O4M3a6Im#,:i&6'J=064"U,9)6'Y$t%Im%C(Im&9E@_N(0(qG,Z
"?`#-m558/<M%"<5/,m^34bEg-b^S4[^oG5B/&!n#W7H$I6AT6Im#8A<O*T-;n.@dPe/NX,.d3;B0E4E
$9^mAIm&9E.m-cn?atSKIm*ckPqre-goM#FIm"H,iXt33LV25"Uc&ss\%Nq>HaHSW::.hcR(/;?=<f%N
Gr0V'M`-AH%6,H9r4N1\3]H]<K!\1V6G1m\+>.9<4Kn]E><;I<,rs&MM7Gf0K!R;@!4R!WBYO8RJM`V%
loG84Im$[mk<%*O?*m?g.m.;o_5reR3k2c-bWEchIQ!TQ4t)m\?TH"[c+E1#D`hX5=>jPGlb&@HM7[%Q
Im&9E4ZnulIm(G,C*lb>Im&9EQ8n_'A[R"NIm)7A'Y1e9U,\Ar[4RBB7^q22Pct<H_mUmA+2I`[h_h4@
>eF=LIC!(dKt?u`e\;^'EjoAcA\9t6'u)i9['308:,RMa3P9f%FuYUG\[U*NIm&9EIm$(\hS"D%YdigV
/A@[fF1g2>\\(2@J%fR.?+UW[1q\4K<5In7fXVg53PZ$1%CEaZe\&H),JB>SotDcd?G0g_pV?:1P;$^c
rk9&Ta"@;!^Un!d=Ln[F(;'jba1[;BaM="PWA$WOf=-_kbINB`Qb&]qPeIeK>IRbJ1q2AI;o+p.k.cEt
TfG*44LKr"@l4"l;nhn*XgcciPJ7(+T=hYEpTq!/0Ji;_Im&9E1-P+\d&_^[f/4:"jL'k%MRbJtIm)sN
H9@HS1H^.MpH*=T\[R&OIm';Xa/rZ-^b%<!Im)=BO#W:_Cq)Db&Nf;32n`?S^H*aHRP(s+mC%'t^b'sp
hE69NIm(_2:-<>QbHY21F?G^Fr\Q,aVR7L*SN@H;<&f@jIm';`Im#hTT!L@=@lJTlDDZu#P.U0<6p,WE
\iP=(Im#hUc90fC)_lh*Im"i0Z`r1@26equIm"i6:-7N!=g(%Ph_\4c(;95t00Jk\Z8_&+4h;@gKX-Os
PWZlECH<(bIm(V1rih;CIm&9E:--Z^B=`RUIm*`j$*YpAr&^Q2*]lMEIAVNV<Ajb9N%9fDXLoT3!BhSY
j1aii*kCFD[(D4,R(qFa;S%q">J;5njh>'&2Qoug1cBhH3kJl^V`4uF+h(rDIm%a6Im&9EHb=hkFJXRO
]K8A:aZNNV_)@FXOt8gK\MS!,F046,qRlPBYrSU4ft!9Q'/uhq"?Fpf%5"M=osk:<_Re"&/&*mMJMo!c
DRl(;nZj.=,d=b_1V"PYik$YP=26o2D8%[+R5>Vb?a=7ON5([fPI,\K0#,<2#HNBgR(QJ1WkQrlDS!A4
n2?K?9tWX!V60a.e@psQ(:eq-*kq]f@(fONM7'Xs;)41oQ9;fAq)nU6E3f*uOYSYs1Uh'Qbdph'Im%L'
h^f$i$F">+4#k_HcF_:]o/W)7agkS0JZa#LH9G(d%kq]XCq#]k">WQYah9S_=g&:EYdTKEA@1neXuJL'
7^Xm#oWC0L]I!$S)8<Gb=gg]2"M>&T^:dpeb-rY/-bSoUXfn(u'!<as28=sPY.-g1/@mLIhnXiZ7D-gY
[CfhU0"KlIh6]V]G.qb#(T\jn-+rr`Nkh4#K"2T027XO8OLj#PbIO^eXhYmd0JR(P4h3PcZbSl@n\.#q
S2u-_h`"UuB0C`-"/Om<Im*cmV)_U<6ahJ-$p;ltRCHE^@60T4-oL+n'!s2EJ182e/[TK&]>$qG.6&un
:r-)DOhVC?Bt]kE7D[?]KXE><WOZ?Go>)fg'#&n3eZDk8T=_Ej)mJTa[(O.4Im"]-M)h"S<56pC/@r\O
QT5gEIm"0%l8q'j&3@Zj.QkO,E'+R`hRWqRIm!lo)6nZSIm'GcK0(eL#;?0@o/=iT)`kbpBYAR?Im)Ae
$RgKfIm)IIAikK*pbbW+W]Yboa>#J4"hd8\Im$+S\MJ^u)DG5U2E3NUE3t*X;a%HHIm&9E]"DH4NAH&I
!\fhG<kHMN*].<64MD:ZiO9B2"2,hiDS05bJ$sa.bcY/5%6X/C#!04O1qeB%oI`]f6*Pte3kd/RYrTk3
hmL_8LUKK)d5(bMC:t]KJ36I`nW?a1YIo.l^G)XoBK3Udr4$W,"#[8)FM9[oV`@nf9/m$N]"%8bZ7#o(
FYUBd^T9:K^bl?M;RsgbE&EP3mB`7i`u%-&,G5(FppE";h5`Fkij?)#ik!A`ftc:Vi4a`WpqE]?!j\<.
c8hu5j"W!fEkEI.*l#P%3P'(C5JV`^'>Uld,eF`'&%j*rkJ3!/MnR0F#f4QoNO)Bg%('cW`kQH!W4bj9
PWXFYIm#hQDEWJ45U#MVIm&9EN'"p<)7Y/ZIm%-u4fEinIm&$;-9\1e<&>a]>IqU.,dni%ke(.UIm*&'
/A1sA_)0*7p(K/CR(U0n\t*Xt$F^AL7)6"),:FtQ,c6&Sagru`S?S27@_5i%Im&9EIm%U1(VYA^ZEkuA
!k)UO5Hi_RNMpX*f!o(s%_X'qHG&g`3kJb)9f<$[D7a8h?aIAR`4e1EEPTN,:Vm[]:Vtf#7D:.^E%Ldu
&@rOj!4T5H*ktLb#K?JRjM=X.[)98g,fCn:1;A(N-GZRqTYPfha1f+"\\O!8*4_WM-b*!aZb];H7DA3!
(c_jRRl2lP]X+3A%DZhkq7<W?0YZV\o":X*Mm5(J7'M2&J38':8NdnO"LNYAK"Llg^Un3jEkJE^L-(:'
Hokk%Im&9E'g:J;HF\MgIm$=aHoE--r3f-KIm%R)aJeMf"M*hX8[Ge6@_Y^H)7Kj]_R'HT9Y5R2*4:5T
PrF=WpGhLs[l@6jOhKnX$o%CbO16IH1qTQmlS[n;3imfo0045:%Q?p3%_S\uMS!*'PIcmg,eh[:qD*l<
;*%cAIm#ML^H$g(J[iobs#X4;fdm@\'Xhs74$5>R$96p'[^CHAn2H[b3PIp?'0:`D8N7bL\\*>IiOP76
GWf1mSiS)WX#pAFY.2#(lo\B49/RbMK=67m1HcF3Ha[HHNAuhW\h.L#Oh5!X-+mS.'tg$GI_SskTqnWu
f=bJ"J[e[l%DBikb.n"gA\@9;Ye>(j/\r75TY"4<r[8CB$b(:<Gr9b+N4c8Q8N^ZLgH7;T)nn$i<kAl%
DS:k?#/+feVnJ/+M84;JBYJl0VnO7g8&<fle%7!C`kP!M+1REDRCg;Gk.^H!A\f;"!l0c16GY.a>IK*t
S\F^)M7-$dTY1K>/\`%2dCaA0hnF]U0Yn43)72rJICnULCqD%)VS3_U-c$)#.D$M3*k2Tg8A[!iG/0!F
\N,VUXL+fXQT"!9#esNE!ObV6NkHsU1:ij`4Z*GOAMm%BIm$jrIm(G$K<tG;I^DqVA@aq0!k/gqIm&T6
83C*=nN;:a:HUm'6b%V/Im$@_$oAMTV^t+nIm%X/DD0O!BY%h5?oT".(r'93aK5QPpo9i:P.'@1PHXmD
Im#2BpH3pgIm(P+Q95^AIm&9E?TUn@IQW*CIm#YLp,/F(Im&9EIm(\2Q8U*R8%J9'[5&)t!jW%mIm&`I
Im*Hb@Qf3(+$ApMIPZI:Im$OOn$DttXL+0RIm'eokGZQJ=LruF]fWGU)(ldaIm%a6Im&9EhQq\p&O"],
Im&9E4?X!5AisQbjL'J#Im&9EE&qi!LphdrIm(Y01GaMD_E>FmIQ/9'FgN2N<4U@0+LQp0NP7fcN]A;l
>J)m:j/TAoK"EM>qRmBA41J>"$+W%-]tmd_fXZLG&i5##F1854H8uU#Dm[2?Im%[4Im&9EWP*dEafr$4
3BVdSIm$mqIm*-\=ZU%UIm&9E@6LYR;RCp:Im'kpf<9ZeIm%F,T0/`-;`K7ih7=B3+1_!M0tb(UIm!lg
NB)JOIm"N06T_#)@'G,DIm"T25<*XG(qS?ZIm)[L^Ti8Oq6$DQd5]*(;7j4sIm#/AIm&9E;7tjM'rlaH
loaAi*]ZeQFsQ%WK>"Lr*O0.`I(THfm^Wq1+$#W@.P7,PIm&NKX?>K%+"i%+5-][Iqm7lYZ+G+bIm*M2
;`nDMIm&9EHogRT$aP7FIm"]0ffH&ko==_&Im#DAoWIRC/\KCiP<(2!GI[l85d1U**3n-I8@W@r]/Mo9
CV*NSk.289]!VIJA&/#R*4Jq\R(CGP+hl.5>.R)7r4]/@MS$j>(9a7<S\@"fg:Y57!kn!8>f-BR+MElQ
J%s"9<4s-]?+RSZO2-skgp^V'VS*YV&A`S+lF`b(F0pn=LU].P:Unca1;T]r^9uY-hRJNWOMP,6rkNKa
'0Uh.Im#_M!^2#rNjcM]Im&9EUcR3kI^jkjIm("q*k6\_Im(e3GW[B:cET/g?b:YB_7-,F%_NE8Im&dt
'YiD&F0`?e<4Wl(<kn\[N4$JY"1X#o[(pamFLmFF+?"^4@^]`*#W0^d,J@/>Im&9EIm&*?7D416['[t8
QatqWQF2RW0s>CG\[qtu+Y=\@*&E0q*km!2BX@9=A&#dcHb&7J-S7cd_RtLV!k_CALUg3k5f&GpK")6(
-,%4$qR$""fs3Q2/%p0`?66JR4Lpk,@_d6%WO-o_G.+BS9sXl,>-tZB5e\BtW\lH<""6AjN5>7rQG,U6
auhdGloM7,l8%S.#/>"(?ab0hijr!t[_"H+/Mi8%4gij&TKCL\a?1e0rjmSB"hSHX%(p)\hn-q5E]\r]
gGsaHIm$Ce=Zi3:fX?8mIm"T14#rln.CSk(Im"Z.<'*`6rNk'6>9+]g2Sbk=)`5=;gG.*QV7YYC>-sa&''')



#
# VaxPress
#
# Copyright 2023 Hyeshik Chang
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# “Software”), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
# NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
# DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
# THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

from . import ScoringFunction

class UridineCountFitness(ScoringFunction):

    single_submission = False

    name = 'ucount'
    description = 'Uridines'
    priority = 30

    arguments = [
        ('weight',
         dict(type=float, default=3.0, metavar='WEIGHT',
              help='scoring weight for U count minimizer (default: 3.0)')),
    ]

    def __init__(self, weight, _length_cds):
        self.weight = -weight / _length_cds * 4

    def score(self, seqs):
        ucounts = [s.count('U') for s in seqs]
        scores = [s * self.weight for s in ucounts]
        return {'ucount': scores}, {'ucount': ucounts}



# Example code that optimizes a sequence to have a specific restriction enzyme
# recognition site.

from vaxpress.scoring import ScoringFunction

class RestrictionSiteFitness(ScoringFunction):

    # True: The scoring function is called with each sequence individually.
    #       This is useful if the scoring function is computationally expensive.
    # False: The scoring function is called with all sequences at once.
    #        This is useful if the scoring function is fast or memory-intensive.
    single_submission = False

    # Prefix in command line arguments, e.g. "--resite-weight"
    name = 'resite'

    # Appears in the help message
    description = 'Restriction Site'

    # Adjusts the order of appearance in the help message. Lower numbers appear
    # first.
    priority = 100

    # Definitions for command line arguments.
    arguments = [
        ('weight', dict(
            type=float,
            default=10.0, # penalize for the violations
            help='scoring weight for the presence of the restriction site '
                 '(default: 10.0)')),
        ('restriction-site', dict(
            default=None, type=str,
            help='restriction site sequence containing only A, C, G, T or '
                 'U (default: None)')),
    ]

    # Argument "_length_cds" is always passed to the constructor. Leave it as
    # it is even if you don't use it.
    def __init__(self, weight, restriction_site, _length_cds):
        self.weight = weight
        self.restriction_site = restriction_site
        if self.restriction_site is None:
            raise EOFError # disable this scoring function

        self.restriction_site = self.restriction_site.upper().replace('T', 'U')
        if set(self.restriction_site) - set('ACGU'):
            raise ValueError('restriction site contains invalid characters')

    # This function is called for every iteration. "seqs" is a list of strings
    # if single_submission is False, or a single string if single_submission is
    # True.
    def score(self, seqs):
        has_site = [] # 0s or 1s indicating existence of site for each sequence.
        scores = [] # fitness values for each sequences. Higher is better.

        for seq in seqs:
            if self.restriction_site in seq:
                found = 1
            else:
                found = 0

            has_site.append(found)
            scores.append(found * self.weight)

        # The first dict should contain the fitness values for each sequence.
        # The second dict may contain the original metrics for it for reference.
        return {'resite': scores}, {'resite': has_site}



# Example code for counting the number of trimers consisted of the consecutive
# same bases

from vaxpress.scoring import ScoringFunction

class HomoTrimerFitness(ScoringFunction):

    single_submission = False

    name = 'homotrimer'
    description = 'Homotrimer Count'
    priority = 110

    arguments = [
        ('weight', dict(
            type=float, default=1.0,
            help='scoring weight for homotrimer count (default: 1.0)')),
    ]

    def __init__(self, weight, _length_cds):
        self.weight = -weight / _length_cds

    def score(self, seqs):
        counts = []
        scores = []
        for seq in seqs:
            hcount = (seq.count('AAA') + seq.count('CCC') +
                      seq.count('GGG') + seq.count('TTT'))
            counts.append(hcount)
            scores.append(hcount * self.weight)
        return {'homotrimer': scores}, {'homotrimer': counts}



#
# VaxPress
#
# Copyright 2023 Hyeshik Chang
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# “Software”), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
# NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
# DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
# THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

import plotly.offline as pyo
import plotly.graph_objects as go
from plotly.subplots import make_subplots
import pandas as pd
import jinja2
import os
import json
import time


class TemplateFiltersMixin:

    @staticmethod
    def filter_localtime(timestamp):
        return time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(timestamp))

    @staticmethod
    def filter_format_bool(value, truevalue, falsevalue):
        return [falsevalue, truevalue][int(value)]

    @staticmethod
    def filter_format_number(value):
        if isinstance(value, float):
            return '{:,.3f}'.format(value).rstrip('0').rstrip('.').replace('-', '−')
        else:
            return str(value).replace('-', '−')

    @staticmethod
    def filter_pluralize(value, singular, plural):
        return [singular, plural][int(value != 1)]

    @classmethod
    def set_filters(kls, env):
        for name in dir(kls):
            if name.startswith('filter_'):
                env.filters[name[7:]] = getattr(kls, name)


class ReportPlotsMixin:

    seq = args = status = scoreopts = iteropts = execopts = None
    checkpoints = None

    default_panel_height = [0, 400, 600, 700, 800] # by number of panels

    def plot_fitness_curve(self, skip_initial=False):
        fig = make_subplots(rows=3, cols=1, shared_xaxes=True, vertical_spacing=0.05)
        view = slice(1, None) if skip_initial else slice(None)

        panel_fitness = go.Scatter(
            x=self.checkpoints.index[view], y=self.checkpoints['fitness'].iloc[view],
            mode='lines', name='Fitness')
        panel_mutation_rate = go.Scatter(
            x=self.checkpoints.index[view],
            y=self.checkpoints['mutation_rate'].iloc[view],
            mode='lines', name='Mutation rate')

        fig.add_trace(panel_fitness, row=1, col=1)

        for name, values in self.checkpoints.items():
            if not name.startswith('score:'):
                continue

            nvalues = values.iloc[view]
            nvalues -= nvalues.mean() # center the score (and don't scale)
            trace = go.Scatter(
                x=self.checkpoints.index[view], y=nvalues,
                mode='lines', name=name[6:])
            fig.add_trace(trace, row=2, col=1)

        fig.add_trace(panel_mutation_rate, row=3, col=1)

        fig.update_layout(
            title='Fitness changes over the iterations',
            height=self.default_panel_height[3])

        fig.update_yaxes(title_text='Total fitness', row=1, col=1)
        fig.update_yaxes(title_text='Fitness score (centered)', row=2, col=1)
        fig.update_yaxes(title_text='Mutation rate', row=3, col=1)
        fig.update_xaxes(title_text='Iteration', row=3, col=1)

        return pyo.plot(fig, output_type='div', include_plotlyjs=False)

    def plot_metric_curves(self, skip_initial=False):
        metrics = self.checkpoints.filter(regex='^metric:').columns

        fig = make_subplots(rows=len(metrics), cols=1, shared_xaxes=True,
                            vertical_spacing=0.02)
        view = slice(1, None) if skip_initial else slice(None)

        for i, name in enumerate(metrics):
            nvalues = self.checkpoints[name].iloc[view]
            trace = go.Scatter(
                x=self.checkpoints.index[view], y=nvalues,
                mode='lines', name=name[7:])
            fig.add_trace(trace, row=i + 1, col=1)
            fig.update_yaxes(title_text=name[7:], row=i + 1, col=1)

        fig.update_layout(
            title='Individual metric change over the iterations',
            height=self.default_panel_height[-1])

        return pyo.plot(fig, output_type='div', include_plotlyjs=False)

    def plot_sequence_evaluation_curves(self):
        plotdata_initial = self.status['evaluations']['initial']['local-metrics']
        plotdata_optimized = self.status['evaluations']['optimized']['local-metrics']
        if not plotdata_initial or not plotdata_optimized:
            return ''

        fig = make_subplots(rows=len(plotdata_initial), cols=1, shared_xaxes=True,
                            vertical_spacing=0.02)

        for i, (metric, values_init) in enumerate(plotdata_initial.items()):
            values_opt = plotdata_optimized[metric]

            trace_init = go.Scatter(x=values_init[0], y=values_init[1],
                                    mode='lines', name=metric + ' (original)',
                                    line=dict(color='gray', width=2, dash='dot'))
            trace_opt = go.Scatter(x=values_opt[0], y=values_opt[1],
                                   mode='lines', name=metric + ' (optimized)')
            fig.add_trace(trace_init, row=i + 1, col=1)
            fig.add_trace(trace_opt, row=i + 1, col=1)
            fig.update_yaxes(title_text=metric, row=i + 1, col=1)

        height = min(len(self.default_panel_height), len(plotdata_initial))
        fig.update_layout(
            title='Final sequence evaluation metrics',
            height=self.default_panel_height[height - 1])

        return pyo.plot(fig, output_type='div', include_plotlyjs=False)


class ReportGenerator(TemplateFiltersMixin, ReportPlotsMixin):

    def __init__(self, status, args, scoreopts, iteropts, execopts, seq,
                 scorefuncs):
        self.seq = seq
        self.args = args
        self.status = status
        self.scoreopts = scoreopts
        self.iteropts = iteropts
        self.execopts = execopts
        self.scorefuncs = scorefuncs

        self.templates = self.load_templates()

    def generate(self):
        params = self.prepare_data()

        for name, template in self.templates.items():
            if name.endswith('.html'):
                output = template.render(**params)
                open(os.path.join(self.execopts.output, name), 'w').write(output)

    def prepare_data(self):
        self.parameters = json.load(open(self.execopts.output + '/parameters.json'))
        self.checkpoints = pd.read_csv(self.execopts.output + '/checkpoints.tsv',
                                       sep='\t', index_col=0)
        scoreopts_filtered = {
            name: {k: v for k, v in opts.items() if not k.startswith('_')}
            for name, opts in self.scoreopts.items()
        }

        return {
            'args': self.args,
            'seq': self.seq,
            'scoring': scoreopts_filtered,
            'iter': self.iteropts,
            'exec': self.execopts,
            'params': self.parameters,
            'status': self.status,
            'checkpoints': self.checkpoints,
            'scorefuncs': self.scorefuncs,
            'plotters': {
                name[5:]: getattr(self, name)
                for name in dir(self)
                if name.startswith('plot_')
            },
        }

    def load_templates(self):
        template_loader = jinja2.PackageLoader('vaxpress', 'report_template')
        env = jinja2.Environment(loader=template_loader)
        self.set_filters(env)

        return {
            name: env.get_template(name)
            for name in env.list_templates()
        }



#
# VaxPress
#
# Copyright 2023 Hyeshik Chang
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# “Software”), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
# NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
# DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
# THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

from . import ScoringFunction
from ..data import codon_usage_data
import numpy as np

class CodonAdaptationIndexFitness(ScoringFunction):

    single_submission = False

    name = 'cai'
    description = 'Codon Adaptation Index'
    priority = 20

    requires = ['mutantgen', 'species']
    arguments = [
        ('weight', dict(
            type=float, default=3.0, metavar='WEIGHT',
            help='scoring weight for codon adaptation index (default: 3.0)'
        )),
    ]

    def __init__(self, weight, _length_cds, _species, _mutantgen):
        self.weight = weight
        self.species = _species
        self.mutantgen = _mutantgen
        self.initialize_codon_scores()

    def initialize_codon_scores(self):
        if self.species not in codon_usage_data.codon_usage:
            raise ValueError(f'No codon usage data for species: {self.species}')

        codon_usage = codon_usage_data.codon_usage[self.species]
        scores = {}
        for aa, codons in self.mutantgen.aa2codons.items():
            codons = sorted(codons)
            freqs = np.array([codon_usage[c] for c in codons])
            scores.update(dict(zip(codons, np.log(freqs / freqs.max()))))

        self.codon_scores = scores

    def score(self, seqs):
        scores = self.codon_scores
        cai = np.array([
            np.mean([scores[seq[i:i+3]] for i in range(0, len(seq), 3)])
            for seq in seqs])
        cai_score = cai * self.weight

        return {'cai': cai_score}, {'cai': cai}

    def evaluate_local(self, seq):
        scores = self.codon_scores
        cai = np.array([scores[seq[i:i+3]] for i in range(0, len(seq), 3)])
        centers = np.arange(0, len(seq), 3) + 1
        return {'cai': (centers, cai)}



#
# VaxPress
#
# Copyright 2023 Hyeshik Chang
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# “Software”), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
# NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
# DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
# THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

from setuptools import setup

setup(
    name='vaxpress',
    version='0.3',
    description='Codon Optimizer for mRNA Vaccine Design',
    author='Hyeshik Chang',
    author_email='hyeshik@snu.ac.kr',
    url='https://github.com/ChangLabSNU/VaxPress',
    download_url='https://github.com/ChangLabSNU/VaxPress/releases',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    keywords=[
        'mRNA vaccine',
        'messenger RNA',
        'codon optimization'
    ],
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
    ],
    packages=['vaxpress', 'vaxpress.scoring', 'vaxpress.data'],
    package_data={'vaxpress': ['report_template/*']},
    data_files=[('share/vaxpress/examples',
        ['examples/count_homotrimers.py', 'examples/restriction_site.py'])],
    entry_points={
        'console_scripts': [
            'vaxpress = vaxpress.__main__:run_vaxpress',
        ],
    },
    install_requires=[
        'biopython >= 1.5',
        'numpy >= 1.15',
        'pandas >= 2.0',
        'pytrf >= 1.0.1',
        'rpy2 >= 3.0',
        'ViennaRNA >= 2.4',
        'tqdm >= 4.0',
        'tabulate >= 0.9',
        'Jinja2 >= 3.1',
        'plotly >= 5.0',
        'pylru >= 1.2',
    ],
    extras_require={
        'nonfree': ['linearfold-unofficial'],
    },
)
